
/****************************************************************************
	'    Copyright  2006 Agilent Technologies Inc. All rights
	'    reserved.
	'
	' You have a royalty-free right to use, modify, reproduce and distribute
	' the Sample Application Files (and/or any modified version) in any way
	' you find useful, provided that you agree that Agilent has no
	' warranty,  obligations or liability for any Sample Application Files.
	'
	' Agilent Technologies provides programming examples for illustration only,
	' This sample program assumes that you are familiar with the programming
	' language being demonstrated and the tools used to create and debug
	' procedures. Agilent support engineers can help explain the
	' functionality of Agilent software components and associated
	' commands, but they will not modify these samples to provide added
	' functionality or construct procedures to meet your specific needs.
 ****************************************************************************/


using System;
using System.Collections.Generic;
using System.Text;

namespace ASCIIArb
{
    class ASCIIArb
    {
        static void Main(string[] args)
        {
            /*
                ' This program is an example program intended for use with
		        ' Microsoft Visual C# and requires the VISA installed.
	        */

            /*
                ' This program uses the arbitrary waveform function to
                ' download and output a square wave pulse with a calculated
                ' rise time and fall time.  The waveform consists of 4000
                ' points downloaded to the function generator as ASCII data.
  
                ' This program commands with channel 1 of the intrument, you can change
                ' the number '1' after each command to '2' to select channel 2.
            */

            string SCPIcmd = "DATA1 VOLATILE, ";
            string strData = "";
            int i;
            double wf;

            bool m_connected = false;
            int m_RsrcMgr = 0;
            int m_TimeOut = 2;
            int m_AccessMode = 0;
            int m_VI = 0;

            // Open Connection
            if (!m_connected)
            {
                visa32.viOpenDefaultRM(out m_RsrcMgr);
                visa32.viOpen(m_RsrcMgr, "GPIB1::11::INSTR", m_AccessMode, m_TimeOut, out m_VI);

                m_connected = true;
            }

            // Compute waveform
            Console.WriteLine("Computing Waveform...");


            // Set rise time (5 points)
            for (i = 1; i <= 5; i++)
            {
                wf = (double)((i - 1) / 5.000);
                strData = string.Concat(strData, wf.ToString(), ", ");

            }

            // Set pulse width (200 points)
            for (i = 6; i <= 205; i++)
            {
                strData = string.Concat(strData, "1,");

            }

            // Set fall time (5 points)
            for (i = 206; i <= 210; i++)
            {
                wf = (double)((210 - i) / 5.000);
                strData = string.Concat(strData, wf.ToString(), ", ");
            }

            // Set remaining points to zero
            for (i = 211; i <= 4000; i++)
            {
                strData = string.Concat(strData, "0,");
            }

            // Delete the last comma "," from the data string
            strData = strData.Remove(strData.Length - 1);

            // Add ASCII data after DATA command
            SCPIcmd = SCPIcmd + strData + "\n";

            // Download data points to volatile memory
            Console.WriteLine("Downloading Arb...");

            visa32.viPrintf(m_VI,SCPIcmd);

            Console.WriteLine("Download Complete");
            // Download data points to volatile memory //

            // Set up arbitrary waveform and output //
            visa32.viPrintf(m_VI, "DATA1:COPY PULSE, VOLATILE\n");  /* Copy arb to non-volatile memory */
            
            visa32.viPrintf(m_VI, "FUNCtion1:USER PULSE\n"); /*  Select the active arb waveform */
            
            visa32.viPrintf(m_VI, "FUNCtion1:SHAPe USER\n"); /* Output the selected arb waveform */
            

            visa32.viPrintf(m_VI, "OUTPut1:LOAD 50\n"); /* Output termination is 50 Ohms */
            
            visa32.viPrintf(m_VI, "FREQuency1 5000;VOLTage 5\n"); /* Output frequency is 5 kHz @ 5 Vpp */
            
            visa32.viPrintf(m_VI, "OUTPut1 ON\n"); /* Enable output */
            



            // Close Connection
            if (m_connected)
            {
                visa32.viClose(m_VI);
                visa32.viClose(m_RsrcMgr);

                m_connected = false;
            }

            Console.WriteLine("Press Enter to continue...");
            Console.ReadLine();
        }
    }
}
