
/****************************************************************************
	'    Copyright  2006 Agilent Technologies Inc. All rights
	'    reserved.
	'
	' You have a royalty-free right to use, modify, reproduce and distribute
	' the Sample Application Files (and/or any modified version) in any way
	' you find useful, provided that you agree that Agilent has no
	' warranty,  obligations or liability for any Sample Application Files.
	'
	' Agilent Technologies provides programming examples for illustration only,
	' This sample program assumes that you are familiar with the programming
	' language being demonstrated and the tools used to create and debug
	' procedures. Agilent support engineers can help explain the
	' functionality of Agilent software components and associated
	' commands, but they will not modify these samples to provide added
	' functionality or construct procedures to meet your specific needs.
 ****************************************************************************/

using System;
using System.Collections.Generic;
using System.Text;

namespace BinaryArb
{
    class BinaryArb
    {
        static void Main(string[] args)
        {
            /*
                ' This program is an example program intended for use with
                ' Microsoft Visual C# and requires the VISA installed.
            */

            /*
                ' This program shows how to down load an arbitrary waveform
                ' using binary data.  The program generates a damped sine
                ' wave using 16,000 points.

  
                ' This program commands with channel 1 of the intrument, you can change
                ' the number '1' after each command to '2' to select channel 2.
             */

            bool m_connected = false;
            int m_RsrcMgr = 0;
            int m_TimeOut = 2;
            int m_AccessMode = 0;
            int m_VI = 0;

            long Ncycles = 10;     // Define number of sinewave cycles
            double Damp_factor = -5; // Define damping factor
            double pi = 3.14159;     // Define pi
            int i;
            short[] waveform = new short[16000];
     

            // Open Connection
            if (!m_connected)
            {
                visa32.viOpenDefaultRM(out m_RsrcMgr);
                visa32.viOpen(m_RsrcMgr, "GPIB1::11::INSTR", m_AccessMode, m_TimeOut, out m_VI);

                m_connected = true;
            }

            visa32.viPrintf(m_VI, "*RST\n");               /* Reset the function generator */
	
	        visa32.viPrintf(m_VI, "FORMat:BORDer SWAP\n"); /* Swap data bytes (send LSB first) */

	        visa32.viPrintf(m_VI, "FREQuency1 5000\n");     /* Output frequency is 5 kHz */
	
	        visa32.viPrintf(m_VI, "OUTPut1:LOAD 50\n");     /* Output termination is 50 Ohms */
	
	        visa32.viPrintf(m_VI, "VOLTage1 5\n");          /* Output amplitude is 5 Vpp */
	
	

	        Console.WriteLine("Computing Waveform...");
		
		
	        /* Calculate data points */
				
	        for (i = 1; i<= 16000; i++)
	        {
		        if(i < 14000)
		        {
			         waveform[i - 1] = (short)(Math.Sin(2 * pi * (double)Ncycles * (double)i / 14000) * 2047
                                       * Math.Exp(Damp_factor * (double)i / 14000) + 0.5);
		        }
		        else
		        {
			        waveform[i-1] = 0;
		        }
	        }
		
	        /* Download data points to volatile memory from array */
		
	        Console.WriteLine("Downloading Arb...");
		

            /*Write IEEEBlock "DATA[1|2]:DAC VOLATILE,", IEEE 488.2 Binary block */
            string cmd = String.Format("DATA1:DAC VOLATILE, %,{0}hd\n", waveform.Length);
            visa32.viPrintf(m_VI, cmd, waveform);
            
	        Console.WriteLine("Download Complete");
		
        	visa32.viPrintf(m_VI, "DATA1:COPY DAMP_SIN, VOLATILE\n"); /* Copy arb to non-volatile memory */
	
	        visa32.viPrintf(m_VI, "FUNCtion1:USER DAMP_SIN\n"); /* Select the active arb waveform */
	
	        visa32.viPrintf(m_VI, "FUNCtion1:SHAPe USER\n");    /* Output the selected arb waveform */
	
	        visa32.viPrintf(m_VI, "OUTPut1 ON\n");              /* Enable output */
	
	

            // Close Connection
            if (m_connected)
            {
                visa32.viClose(m_VI);
                visa32.viClose(m_RsrcMgr);

                m_connected = false;
            }

            Console.WriteLine("Press Enter to continue...");
            Console.ReadLine();
        }
    }
}
