
/****************************************************************************
	'    Copyright  2006 Agilent Technologies Inc. All rights
	'    reserved.
	'
	' You have a royalty-free right to use, modify, reproduce and distribute
	' the Sample Application Files (and/or any modified version) in any way
	' you find useful, provided that you agree that Agilent has no
	' warranty,  obligations or liability for any Sample Application Files.
	'
	' Agilent Technologies provides programming examples for illustration only,
	' This sample program assumes that you are familiar with the programming
	' language being demonstrated and the tools used to create and debug
	' procedures. Agilent support engineers can help explain the
	' functionality of Agilent software components and associated
	' commands, but they will not modify these samples to provide added
	' functionality or construct procedures to meet your specific needs.
 ****************************************************************************/

using System;
using System.Collections.Generic;
using System.Text;

namespace FSK
{
    class FSK
    {
        static void Main(string[] args)
        {
            /*
                ' This program is an example program intended for use with
		        ' Microsoft Visual C# and requires the VISA installed.
	        */

            /*

                ' This program uses low-level SCPI commands to configure
                ' the function generator to output an FSK waveform.
                ' This program also shows the use of a trigger received
                ' over the GPIB interface to initiate a single trigger.
    
                ' This program commands with channel 1 of the intrument, you can change
                ' the number '1' after each command to '2' to select channel 2.
    
            */

            bool m_connected = false;
            int m_RsrcMgr = 0;
            int m_TimeOut = 2;
            int m_AccessMode = 0;
            int m_VI = 0;

            // Open Connection
            if (!m_connected)
            {
                visa32.viOpenDefaultRM(out m_RsrcMgr);
                visa32.viOpen(m_RsrcMgr, "GPIB1::11::INSTR", m_AccessMode, m_TimeOut, out m_VI);

                m_connected = true;
            }

            visa32.viPrintf(m_VI, "*RST\n");  /* Reset the function generator */
            

            visa32.viPrintf(m_VI, "OUTPut1:LOAD 50\n");  /*  Output termination is 50 Ohms */
            
            visa32.viPrintf(m_VI, "FUNCtion1:SHAPe SINusoid\n");  /* Carrier waveshape is sine wave */
            
            visa32.viPrintf(m_VI, "FREQuency1 5000;VOLTage 5\n");  /* Carrier frequency is 5 kHz @ 5 Vpp */
            
            visa32.viPrintf(m_VI, "FSKey1:FREQuency 200\n");  /*  FSK 'hop'frequency is 200 Hz */
            
            visa32.viPrintf(m_VI, "FSKey1:INTernal:RATE 20\n");  /* Rate at which the output frequency 'shifts' is 20 Hz */
            
            visa32.viPrintf(m_VI, "FSKey1:SOURce INTernal\n");  /* Use internal signal for modulation */
            
            visa32.viPrintf(m_VI, "TRIGger1:SOURce BUS\n");  /*  Trigger source is "bus" */
            
            visa32.viPrintf(m_VI, "FSKey1:STATe ON\n");  /* Turn FSK modulation On */
            
            visa32.viPrintf(m_VI, "OUTPut1 ON\n");  /* Turn on the instrument output */
            

            /* Trigger the function generator over the GPIB interface	*/

            visa32.viPrintf(m_VI, "*TRG\n");
            
		

            // Close Connection
            if (m_connected)
            {
                visa32.viClose(m_VI);
                visa32.viClose(m_RsrcMgr);

                m_connected = false;
            }

            Console.WriteLine("Press Enter to continue...");
            Console.ReadLine();
        }
    }
}
