/****************************************************************************
	'    Copyright  2006 Agilent Technologies Inc. All rights
	'    reserved.
	'
	' You have a royalty-free right to use, modify, reproduce and distribute
	' the Sample Application Files (and/or any modified version) in any way
	' you find useful, provided that you agree that Agilent has no
	' warranty,  obligations or liability for any Sample Application Files.
	'
	' Agilent Technologies provides programming examples for illustration only,
	' This sample program assumes that you are familiar with the programming
	' language being demonstrated and the tools used to create and debug
	' procedures. Agilent support engineers can help explain the
	' functionality of Agilent software components and associated
	' commands, but they will not modify these samples to provide added
	' functionality or construct procedures to meet your specific needs.
 ****************************************************************************/

using System;
using System.Collections.Generic;
using System.Text;

namespace LowLevel
{
    class LowLevel
    {
        static void Main(string[] args)
        {
            /*
                ' This program is an example program intended for use with
                ' Microsoft Visual C# and requires the VISA installed
            */

            /*
                ' This program uses low-level SCPI commands to configure
                ' the function gnerator to output an AM waveform.
                ' This program also shows how to use "state storage" to
                ' store the instrument configuration in memory.

  
                ' This program commands with channel 1 of the intrument, you can change
                ' the number '1' after each command to '2' to select channel 2.
             */
            
            bool m_connected = false;
            int m_RsrcMgr = 0;
            int m_TimeOut = 2;
            int m_AccessMode = 0;
            int m_VI = 0;
          
            // Open Connection
            if (!m_connected)
            {
                visa32.viOpenDefaultRM(out m_RsrcMgr);
                visa32.viOpen(m_RsrcMgr, "GPIB1::11::INSTR", m_AccessMode, m_TimeOut, out m_VI);
                m_connected = true;
            }

           

            visa32.viPrintf(m_VI, "*RST\n");  /* Reset the function generator */
            visa32.viClear(m_VI); /* Clear errors and status registers */

            visa32.viPrintf(m_VI, "OUTPut1:LOAD 50\n");  /* Output termination is 50 Ohms */
           
            visa32.viPrintf(m_VI, "FUNCtion1:SHAPe SINusoid\n");        /* Carrier waveshape is sine wave*/
           
            visa32.viPrintf(m_VI, "FREQuency1 5000;VOLTage 5\n");       /* Carrier frequency is 5 kHz @ 5 Vpp */
           
            visa32.viPrintf(m_VI, "AM1:INTernal:FUNCtion SINusoid\n");  /* Modulating waveshape is sine */
           
            visa32.viPrintf(m_VI, "AM1:INTernal:FREQuency 200\n");     /* Modulation frequency is 200 Hz */
           
            visa32.viPrintf(m_VI, "AM1:DEPTh 80\n");     /* Modulation depth is 80% */
           
            visa32.viPrintf(m_VI, "AM1:STATe ON\n");     /* Turn AM modulation on */
           

            visa32.viPrintf(m_VI, "OUTPut1 ON\n");  /* Turn on the instrument output */
           
            visa32.viPrintf(m_VI, "*SAV 1\n");     /* Store state in memory location 1 */
           

            /* Use the "*RCL 1" command to recall the stored state */

            
            // Close Connection
            if (m_connected)
            {
                visa32.viClose(m_VI);
                visa32.viClose(m_RsrcMgr);

                m_connected = false;
            }

            Console.WriteLine("Press Enter to continue...");
            Console.ReadLine();
        }
    }
}
