
/****************************************************************************
	'    Copyright  2006 Agilent Technologies Inc. All rights
	'    reserved.
	'
	' You have a royalty-free right to use, modify, reproduce and distribute
	' the Sample Application Files (and/or any modified version) in any way
	' you find useful, provided that you agree that Agilent has no
	' warranty,  obligations or liability for any Sample Application Files.
	'
	' Agilent Technologies provides programming examples for illustration only,
	' This sample program assumes that you are familiar with the programming
	' language being demonstrated and the tools used to create and debug
	' procedures. Agilent support engineers can help explain the
	' functionality of Agilent software components and associated
	' commands, but they will not modify these samples to provide added
	' functionality or construct procedures to meet your specific needs.
 ****************************************************************************/


using System;
using System.Collections.Generic;
using System.Threading;
using System.Text;

namespace Pulse
{
    class Pulse
    {
        static void Main(string[] args)
        {
            /*
             * This program is an example program intended for use with
             * Microsoft Visual C# and requires the VISA installed.
            */

            /*
             * This program sets up a pulse waveshape and adjusts the edge
             * time.  It also shows the use of high and low voltage levels
             * and period.  The edge time is adjusted by 5 nsec increments.

  
            ' This program commands with channel 1 of the intrument, you can change
            ' the number '1' after each command to '2' to select channel 2.
             */

            bool m_connected = false;
            int m_RsrcMgr = 0;
            int m_TimeOut = 2;
            int m_AccessMode = 0;
            int m_VI = 0;
            int i;
            string SCPIcmd = "";
            double time;

            // Open Connection
            if (!m_connected)
            {
                visa32.viOpenDefaultRM(out m_RsrcMgr);
                visa32.viOpen(m_RsrcMgr, "GPIB1::11::INSTR", m_AccessMode, m_TimeOut, out m_VI);

                m_connected = true;
            }

            visa32.viPrintf(m_VI, "*RST\n");  /* Reset the function generator */
            
            visa32.viPrintf(m_VI, "*CLS\n");  /* Clear errors and status registers */
            

            visa32.viPrintf(m_VI, "FUNCtion1 PULSe\n");  /* Select pulse waveshape */
            

            visa32.viPrintf(m_VI, "OUTPut1:LOAD 50\n"); /* Set the load impedance in Ohms (50 Ohms default) */
            
            visa32.viPrintf(m_VI, "VOLTage1:LOW 0;:VOLTage:HIGH 0.75\n");  /* Low level = 0 V, High level = .75 V */
            

            visa32.viPrintf(m_VI, "PULSe1:PERiod 1e-3\n");  /* 1 ms intervals */
            
            visa32.viPrintf(m_VI, "PULSe1:WIDTh 100e-6\n");  /* Pulse width is 100 us */
            
            visa32.viPrintf(m_VI, "PULSe1:TRANsition 10e-9\n");  /* Edge time is 10 ns (rise time = fall time) */
            
            visa32.viPrintf(m_VI, "OUTPut1 ON\n");  /* Turn on the instrument output */
            

            for (i = 0; i <= 18; i++)
            {
                time = 0.00000001 + i * 0.000000005; /* Vary edge by 5 nsec steps */
                SCPIcmd = "PULSe1:TRANsition " + time.ToString() + "\n";
                
                visa32.viPrintf(m_VI,SCPIcmd);
                Thread.Sleep(300); /* Wait 300 msec */
            }

            // Close Connection
            if (m_connected)
            {
                visa32.viClose(m_VI);
                visa32.viClose(m_RsrcMgr);

                m_connected = false;
            }

            Console.WriteLine("Press Enter to continue...");
            Console.ReadLine();
        }
    }
}
