
/****************************************************************************
	'    Copyright  2006 Agilent Technologies Inc. All rights
	'    reserved.
	'
	' You have a royalty-free right to use, modify, reproduce and distribute
	' the Sample Application Files (and/or any modified version) in any way
	' you find useful, provided that you agree that Agilent has no
	' warranty,  obligations or liability for any Sample Application Files.
	'
	' Agilent Technologies provides programming examples for illustration only,
	' This sample program assumes that you are familiar with the programming
	' language being demonstrated and the tools used to create and debug
	' procedures. Agilent support engineers can help explain the
	' functionality of Agilent software components and associated
	' commands, but they will not modify these samples to provide added
	' functionality or construct procedures to meet your specific needs.
 ****************************************************************************/

using System;
using System.Collections.Generic;
using System.Text;

namespace PulseWidthMod
{
    class PulseWidthMod
    {
        static void Main(string[] args)
        {
            /*
	         * This example program is adapted for 
	         * Microsoft Visual C# and requires the VISA installed
	        */

            /*
             * This program uses low-level SCPI commands to configure
             * the function gnerator to output an PWM waveform.
             * The pulse is set up with a duty cycle of 35% and a depth
             * of 15%, and will vary in width from 20% to 50% with the
             * modulation.  The pulse may also be configured in time
             * units (pulse width and deviation) rather than duty cycle 
             * if preferred.

  
            ' This program commands with channel 1 of the intrument, you can change
            ' the number '1' after each command to '2' to select channel 2.
             */

            bool m_connected = false;
            int m_RsrcMgr = 0;
            int m_TimeOut = 2;
            int m_AccessMode = 0;
            int m_VI = 0;

            // Open Connection
            if (!m_connected)
            {
                visa32.viOpenDefaultRM(out m_RsrcMgr);
                visa32.viOpen(m_RsrcMgr, "GPIB1::11::INSTR", m_AccessMode, m_TimeOut, out m_VI);

                m_connected = true;
            }

            visa32.viPrintf(m_VI, "*RST\n");                           /* Reset the function generator */
            

            visa32.viPrintf(m_VI, "OUTPut1:LOAD 50\n");                /* Output termination is 50 Ohms */
            
            visa32.viPrintf(m_VI, "FUNCtion1:SHAPe PULSe\n");          /* Carrier waveshape is pulse */
            
            visa32.viPrintf(m_VI, "FREQuency1 5000\n");                 /* Carrier frequency is 5 kHz */
            
            visa32.viPrintf(m_VI, "VOLTage1:LOW 0\n");                 /* Set parameters to 5 V TTL */
            
            visa32.viPrintf(m_VI, "VOLTage1:HIGH 5\n");
            
            visa32.viPrintf(m_VI, "FUNCtion1:PULSe:DCYCle 35\n");     /* Begin with 35% duty cycle */
            

            visa32.viPrintf(m_VI, "PWM1:INTernal:FUNCtion TRIangle\n"); /* Modulating waveshape is triangle */
            
            visa32.viPrintf(m_VI, "PWM1:INTernal:FREQuency 2\n");       /* Modulation frequency is 2 Hz */
            
            visa32.viPrintf(m_VI, "PWM1:DEViation:DCYCle 15\n");        /* Modulation depth is 15% */
            
            visa32.viPrintf(m_VI, "PWM1:SOURce INTernal\n");           /* Use internal signal for modulation */
            
            /*  
             * If using an external signal for PWM, connect the signal to the rear-panel
             * BNC and use the command PWM:SOURce EXTernal
             */
            visa32.viPrintf(m_VI, "PWM1:STATe ON\n");                  /* Turn PWM modulation on */
            

            visa32.viPrintf(m_VI, "OUTPut1 ON\n");                      /* Turn on the instrument output */
            

            // Close Connection
            if (m_connected)
            {
                visa32.viClose(m_VI);
                visa32.viClose(m_RsrcMgr);

                m_connected = false;
            }

            Console.WriteLine("Press Enter to continue...");
            Console.ReadLine();
        }
    }
}
