
/****************************************************************************
	'    Copyright  2006 Agilent Technologies Inc. All rights
	'    reserved.
	'
	' You have a royalty-free right to use, modify, reproduce and distribute
	' the Sample Application Files (and/or any modified version) in any way
	' you find useful, provided that you agree that Agilent has no
	' warranty,  obligations or liability for any Sample Application Files.
	'
	' Agilent Technologies provides programming examples for illustration only,
	' This sample program assumes that you are familiar with the programming
	' language being demonstrated and the tools used to create and debug
	' procedures. Agilent support engineers can help explain the
	' functionality of Agilent software components and associated
	' commands, but they will not modify these samples to provide added
	' functionality or construct procedures to meet your specific needs.
 ****************************************************************************/


using System;
using System.Collections.Generic;
using System.Text;

namespace SimpleSine
{
    class SimpleSine
    {
        static void Main(string[] args)
        {
            /*
                ' This program is an example program intended for use with
                ' Microsoft Visual C# and requires the VISA installed.
            */

            /*
                ' This program sets up a waveform by selecting the waveshape
                ' and adjusting the frequency, amplitude, and offset.
    
                ' This program shows how to commands with 2 channel by inserting
                ' the number '1' after the command to select channel 1 and the number '2'
                ' to select channel 2 in order to set up different waveform parameters.

             */

            bool m_connected = false;
            int m_RsrcMgr = 0;
            int m_TimeOut = 2;
            int m_AccessMode = 0;
            int m_VI = 0;

            // Open Connection
            if (!m_connected)
            {
                visa32.viOpenDefaultRM(out m_RsrcMgr);
                visa32.viOpen(m_RsrcMgr, "GPIB1::11::INSTR", m_AccessMode, m_TimeOut, out m_VI);

                m_connected = true;
            }

            visa32.viPrintf(m_VI, "*RST\n");  /* Reset the function generator */
            
            visa32.viPrintf(m_VI, "*CLS\n");  /* Clear errors and status registers */
            

            // Channel 1
            visa32.viPrintf(m_VI, "FUNCtion1 SINusoid\n");  /* Select waveshape */
            /* Other options are SQUare, RAMP, PULSe, NOISe, DC, and USER */
            

            visa32.viPrintf(m_VI, "OUTPut1:LOAD 50\n"); /* Set the load impedance in Ohms (50 Ohms default) */
            /* May also be INFinity, as when using oscilloscope or DMM */
            

            visa32.viPrintf(m_VI, "FREQuency1 2500\n"); /* Set the frequency */
            

            visa32.viPrintf(m_VI, "VOLTage1 1.2\n");  /*Set the amplitude in Vpp.  Also see VOLTage:UNIT */
            

            visa32.viPrintf(m_VI, "VOLTage1:OFFSet 0.4\n"); /* Set the offset in Volts */
            
            

            visa32.viPrintf(m_VI, "OUTPut1 ON\n");  /* Turn on the instrument output */
            


            // Channel 2
            visa32.viPrintf(m_VI, "FUNCtion2 SINusoid\n");  /* Select waveshape */
            /* Other options are SQUare, RAMP, PULSe, NOISe, DC, and USER */
            

            visa32.viPrintf(m_VI, "OUTPut2:LOAD 50\n"); /* Set the load impedance in Ohms (50 Ohms default) */
            /* May also be INFinity, as when using oscilloscope or DMM */

            visa32.viPrintf(m_VI, "FREQuency2 5000\n"); /* Set the frequency */
            

            visa32.viPrintf(m_VI, "VOLTage2 2\n");  /*Set the amplitude in Vpp.  Also see VOLTage:UNIT */
            

            visa32.viPrintf(m_VI, "VOLTage2:OFFSet 1\n"); /* Set the offset in Volts */
            /* Voltage may also be set as VOLTage:HIGH and VOLTage:LOW for low level and high level */

            visa32.viPrintf(m_VI, "OUTPut2 ON\n");  /* Turn on the instrument output */
            

            // Close Connection
            if (m_connected)
            {
                visa32.viClose(m_VI);
                visa32.viClose(m_RsrcMgr);

                m_connected = false;
            }

            Console.WriteLine("Press Enter to continue...");
            Console.ReadLine();

        }
    }
}
