
/****************************************************************************
	'    Copyright  2006 Agilent Technologies Inc. All rights
	'    reserved.
	'
	' You have a royalty-free right to use, modify, reproduce and distribute
	' the Sample Application Files (and/or any modified version) in any way
	' you find useful, provided that you agree that Agilent has no
	' warranty,  obligations or liability for any Sample Application Files.
	'
	' Agilent Technologies provides programming examples for illustration only,
	' This sample program assumes that you are familiar with the programming
	' language being demonstrated and the tools used to create and debug
	' procedures. Agilent support engineers can help explain the
	' functionality of Agilent software components and associated
	' commands, but they will not modify these samples to provide added
	' functionality or construct procedures to meet your specific needs.
 ****************************************************************************/

using System;
using System.Collections.Generic;
using System.Threading;
using System.Text;

namespace SquareBurst
{
    class SquareBurst
    {
        static void Main(string[] args)
        {
            /*
                ' This program is an example program intended for use with
                ' Microsoft Visual C# and requires the VISA installed.
            */

            /*
                ' This program sets up a triggered burst that outputs three
                ' cycles of a square wave upon receipt of each trigger.  It
                ' will also show how to adjust duty cycle and enable/disable
                ' the SYNC output

  
                ' This program commands with channel 1 of the intrument, you can change
                ' the number '1' after each command to '2' to select channel 2.
             */

            bool m_connected = false;
            int m_RsrcMgr = 0;
            int m_TimeOut = 2;
            int m_AccessMode = 0;
            int m_VI = 0;
            int i;

            // Open Connection
            if (!m_connected)
            {
                visa32.viOpenDefaultRM(out m_RsrcMgr);
                visa32.viOpen(m_RsrcMgr, "GPIB1::11::INSTR", m_AccessMode, m_TimeOut, out m_VI);

                m_connected = true;
            }

            visa32.viPrintf(m_VI, "*RST\n");  /* Reset the function generator */
            
            visa32.viPrintf(m_VI, "*CLS\n");  /* Clear errors and status registers */
            

            visa32.viPrintf(m_VI, "OUTPut1:SYNC OFF\n");  /* Disable the SYNC Output */
            
            visa32.viPrintf(m_VI, "FUNCtion1 SQUare\n");  /* Select waveshape */
            
            visa32.viPrintf(m_VI, "FUNCtion1:SQUare:DCYCle 20\n");  /* 20% duty cycle */
            

            visa32.viPrintf(m_VI, "OUTPut1:LOAD 50\n");  /* Set the load impedance to 50 Ohms (default) */
            
            visa32.viPrintf(m_VI, "VOLTage1 1\n");  /* Set the amplitude to 1 Vpp. */
            
            visa32.viPrintf(m_VI, "VOLTage1:OFFSet 0\n");  /* Set the offset to 0 V */
            
            visa32.viPrintf(m_VI, "FREQuency1 20e3\n");  /* Frequency at 20 kHz */
            

            visa32.viPrintf(m_VI, "TRIGger1:SOURce BUS\n");  /* Triggers will be received from the I/O bus */
            
            visa32.viPrintf(m_VI, "BURSt1:MODE TRIGgered\n");  /* Triggered burst (rather than GATed) */
            
            visa32.viPrintf(m_VI, "BURSt1:NCYCles 3\n");  /* 3 cycles will be output per trigger */
            
            visa32.viPrintf(m_VI, "BURSt1:STATe ON\n");  /* Enable burst */
            

            visa32.viPrintf(m_VI, "OUTPut1:SYNC ON\n");  /* Enable the SYNC Output to trigger oscilloscope */
            
            visa32.viPrintf(m_VI, "OUTPut1 ON\n");  /* Turn on the instrument output */
            

            for (i = 1; i <= 20; i++)
            {
                visa32.viPrintf(m_VI, "*TRG\n");  /* Send bus trigger */

                Thread.Sleep(100); /* Wait 100 msec */
            }


            // Close Connection
            if (m_connected)
            {
                visa32.viClose(m_VI);
                visa32.viClose(m_RsrcMgr);

                m_connected = false;
            }

            Console.WriteLine("Press Enter to continue...");
            Console.ReadLine();
        }
    }
}
