
/****************************************************************************
	'    Copyright  2006 Agilent Technologies Inc. All rights
	'    reserved.
	'
	' You have a royalty-free right to use, modify, reproduce and distribute
	' the Sample Application Files (and/or any modified version) in any way
	' you find useful, provided that you agree that Agilent has no
	' warranty,  obligations or liability for any Sample Application Files.
	'
	' Agilent Technologies provides programming examples for illustration only,
	' This sample program assumes that you are familiar with the programming
	' language being demonstrated and the tools used to create and debug
	' procedures. Agilent support engineers can help explain the
	' functionality of Agilent software components and associated
	' commands, but they will not modify these samples to provide added
	' functionality or construct procedures to meet your specific needs.
 ****************************************************************************/

using System;
using System.Collections.Generic;
using System.Text;
using BASICFORMATTEDIOLib;
using VisaComLib;

//
// This program is an example program intended for use with
// Microsoft Visual C# and the Agilent VISA COM objects.
//
// "VISA COM 1.0 Type Library", corresponds to VISACOM.tlb
// "Agilent VISA COM Resource Manager 1.0", corresponds to AgtRM.DLL
//
// Use the statement "using VisaComLib;" to import 
// the VISA COM type library. 
//

namespace ASCIIArb
{
    class ASCIIArb
    {
        static void Main(string[] args)
        {
            string SCPIcmd, strData;
            int i;
            double wf;

            AgilentRMLib.SRMClsClass m_rm = null;
            VisaComLib.FormattedIO488Class m_fmio = null;

            VisaComLib.IVisaSession m_session = null;
            bool m_connected = false;
            string m_instrument = "GPIB1::11::INSTR";

            m_rm = new AgilentRMLib.SRMClsClass();
            m_fmio = new FormattedIO488Class();

            // Open Connection
            if (!m_connected)
            {
                m_session = m_rm.Open(m_instrument, AccessMode.NO_LOCK, 4000, "");
                m_fmio.IO = (IMessage)m_session;
                m_connected = true;
            }

            // This program uses the arbitrary waveform function to
            // download and output a square wave pulse with a calculated
            // rise time and fall time.  The waveform consists of 4000
            // points downloaded to the function generator as ASCII data.

            /*
                ' This program commands with channel 1 of the intrument, you can change
                ' the number '1' after each command to '2' to select channel 2.
            */


            m_fmio.WriteString("*RST", true);	// Reset the function generator
            m_fmio.IO.Clear();	// Clear errors and status registers
            m_fmio.IO.Timeout = 40000;				// Set 40 seconds timeout

            SCPIcmd = "DATA1 VOLATILE, ";
            strData = "";
        
            // Compute waveform
            Console.WriteLine("Computing Waveform...");

 
            // Set rise time (5 points)
            for (i = 1; i <= 5; i++)				
            {
                wf = (double)((i - 1) / 5.000);
                strData = string.Concat(strData,wf.ToString(),", ");
                
            }

            // Set pulse width (200 points)
            for (i = 6; i <= 205; i++)
            {
                strData = string.Concat(strData,"1,");
       			
            }

            // Set fall time (5 points)
            for (i = 206; i <= 210; i++)			
            {
                wf = (double)((210 - i) / 5.000);
                strData = string.Concat(strData,wf.ToString(), ", ");
            }

            // Set remaining points to zero
            for (i = 211; i <= 4000; i++)
            {
                strData = string.Concat(strData, "0,");
            }

            // Delete the last comma "," from the data string
            strData = strData.Remove(strData.Length-1);

            // Add ASCII data after DATA command
            SCPIcmd = SCPIcmd + strData;

            // Download data points to volatile memory
            Console.WriteLine("Downloading Arb...");

            m_fmio.WriteString(SCPIcmd,true);

            Console.WriteLine("Download Complete");
            // Download data points to volatile memory //

            // Set up arbitrary waveform and output //

            m_fmio.WriteString("DATA1:COPY PULSE, VOLATILE",true);	// Copy arb to non-volatile memory
            m_fmio.WriteString("FUNCtion1:USER PULSE",true);		// Select the active arb waveform
            m_fmio.WriteString("FUNCtion1:SHAPe USER",true);		// Output the selected arb waveform

            m_fmio.WriteString("OUTPut1:LOAD 50",true);				// Output termination is 50 Ohms
            m_fmio.WriteString("FREQuency1 5000;VOLTage 5",true);	// Output frequency is 5 kHz @ 5 Vpp
            m_fmio.WriteString("OUTPut1 ON",true);					// Enable output

            // Close Connection
            if (m_connected)
            {
                m_session.Close();
                m_connected = false;
            }
            Console.WriteLine("Press Enter to Continue...");
            Console.ReadLine();
        }
    }
}
