
/****************************************************************************
	'    Copyright  2006 Agilent Technologies Inc. All rights
	'    reserved.
	'
	' You have a royalty-free right to use, modify, reproduce and distribute
	' the Sample Application Files (and/or any modified version) in any way
	' you find useful, provided that you agree that Agilent has no
	' warranty,  obligations or liability for any Sample Application Files.
	'
	' Agilent Technologies provides programming examples for illustration only,
	' This sample program assumes that you are familiar with the programming
	' language being demonstrated and the tools used to create and debug
	' procedures. Agilent support engineers can help explain the
	' functionality of Agilent software components and associated
	' commands, but they will not modify these samples to provide added
	' functionality or construct procedures to meet your specific needs.
 ****************************************************************************/

using System;
using System.Collections.Generic;
using System.Text;
using BASICFORMATTEDIOLib;
using VisaComLib;

//
// This program is an example program intended for use with
// Microsoft Visual C# and the Agilent VISA COM objects.
//
// "VISA COM 1.0 Type Library", corresponds to VISACOM.tlb
// "Agilent VISA COM Resource Manager 1.0", corresponds to AgtRM.DLL
//
// Use the statement "using VisaComLib;" to import 
// the VISA COM type library. 
//

namespace BinaryArb
{
    class BinaryArb
    {
        static void Main(string[] args)
        {
            long Ncycles = 10;     // Define number of sinewave cycles
            double Damp_factor = -5; // Define damping factor
            double pi = 3.14159;     // Define pi
            long i;
            short[] waveform = new short[524288];

            AgilentRMLib.SRMClsClass m_rm = null;
            VisaComLib.FormattedIO488Class m_fmio = null;

            VisaComLib.IVisaSession m_session = null;
            bool m_connected = false;
            string m_instrument = "GPIB1::11::INSTR";

            m_rm = new AgilentRMLib.SRMClsClass();
            m_fmio = new FormattedIO488Class();

            if (!m_connected)
            {
                m_session = m_rm.Open(m_instrument, AccessMode.NO_LOCK, 4000, "");
                m_fmio.IO = (IMessage)m_session;
                m_connected = true;
            }

            // This program shows how to down load an arbitrary waveform
            // using binary data.  The program generates a damped sine
            // wave using 512k (524288) points.		

            /*
                ' This program commands with channel 1 of the intrument, you can change
                ' the number '1' after each command to '2' to select channel 2.
            */

            m_fmio.IO.Timeout = 40000;			  // Set 40 seconds timeout.
            m_fmio.WriteString("*RST",true); // Reset the function generator
            m_fmio.IO.Clear();					  // Clear errors and status registers
            
            m_fmio.WriteString("FORMat:BORDer NORMal",true); // Normal order data bytes (send MSB first)
            m_fmio.WriteString("FREQuency1 5000",true);		// Output frequency is 5 kHz
            m_fmio.WriteString("OUTPut1:LOAD 50",true);		// Output termination is 50 Ohms
            m_fmio.WriteString("VOLTage1 5",true);			// Output amplitude is 5 Vpp

            

            //
            // Calculate data points
            //

            Console.WriteLine("Computing Waveform...");

            for (i = 1; i <= 524288; i++)
            {
                
                if (i < 524000)
                {
                    waveform[i - 1] = (short)(Math.Sin(2 * pi * (double)Ncycles * (double)i / 524000) * 2047
                                 * Math.Exp(Damp_factor * (double)i / 524000) + 0.5);
                }
                else
                {
                    waveform[i-1] = 0;
                }
            
            }
            // Download data points to volatile memory from array //
            Console.WriteLine("Downloading Arb...");

            // Write IEEEBlock "DATA:DAC VOLATILE,", IEEE 488.2 Binary block
            m_fmio.WriteIEEEBlock("DATA1:DAC VOLATILE,", waveform, true);
              
            m_fmio.WriteString("*OPC?",true);
            m_fmio.ReadString();

            Console.WriteLine("Download Complete");

            m_fmio.WriteString("DATA1:COPY DAMP_SIN, VOLATILE", true);	// Copy arb to non-volatile memory
            m_fmio.WriteString("FUNCtion1:USER DAMP_SIN",true);		// Select the active arb waveform
            m_fmio.WriteString("FUNCtion1:SHAPe USER",true);			// Output the selected arb waveform
            m_fmio.WriteString("OUTPut1 ON",true);						// Enable output
          
            if (m_connected)
            {
                m_session.Close();
                m_connected = false;
            }
            Console.WriteLine("Press Enter to Continue...");
            Console.ReadLine();
        }
    }
}
