
/****************************************************************************
	'    Copyright  2006 Agilent Technologies Inc. All rights
	'    reserved.
	'
	' You have a royalty-free right to use, modify, reproduce and distribute
	' the Sample Application Files (and/or any modified version) in any way
	' you find useful, provided that you agree that Agilent has no
	' warranty,  obligations or liability for any Sample Application Files.
	'
	' Agilent Technologies provides programming examples for illustration only,
	' This sample program assumes that you are familiar with the programming
	' language being demonstrated and the tools used to create and debug
	' procedures. Agilent support engineers can help explain the
	' functionality of Agilent software components and associated
	' commands, but they will not modify these samples to provide added
	' functionality or construct procedures to meet your specific needs.
 ****************************************************************************/

using System;
using System.Collections.Generic;
using System.Text;
using BASICFORMATTEDIOLib;
using VisaComLib;

//
// This program is an example program intended for use with
// Microsoft Visual C# and the Agilent VISA COM objects.
//
// "VISA COM 1.0 Type Library", corresponds to VISACOM.tlb
// "Agilent VISA COM Resource Manager 1.0", corresponds to AgtRM.DLL
//
// Use the statement "using VisaComLib;" to import 
// the VISA COM type library. 
//

namespace FSK
{
    class FSK
    {
        static void Main(string[] args)
        {
            AgilentRMLib.SRMClsClass m_rm = null;
            VisaComLib.FormattedIO488Class m_fmio = null;

            VisaComLib.IVisaSession m_session = null;
            bool m_connected = false;
            string m_instrument = "GPIB1::11::INSTR";

            m_rm = new AgilentRMLib.SRMClsClass();
            m_fmio = new FormattedIO488Class();
            
            // Open Connection  	
            if (!m_connected)
            {
                m_session = m_rm.Open(m_instrument, AccessMode.NO_LOCK, 4000, "");
                m_fmio.IO = (IMessage)m_session;
                m_connected = true;
            }

            //' This program uses low-level SCPI commands to configure
            //' the function generator to output an FSK waveform.
            //' This program also shows the use of a trigger received
            //' over the GPIB interface to initiate a single trigger.

            //' This program commands with channel 1 of the intrument, you can change
            //' the number '1' after each command to '2' to select channel 2.

            m_fmio.WriteString("*RST", true); // Reset the function generator
            
            m_fmio.WriteString("*CLS",true); // Clear errors and status registers

            m_fmio.WriteString("OUTPut1:LOAD 50",true); // Output termination is 50 Ohms
            m_fmio.WriteString("FUNCtion1:SHAPe SINusoid",true); // Carrier waveshape is sine wave
            m_fmio.WriteString("FREQuency1 5000;VOLTage 5",true); // Carrier frequency is 5 kHz @ 5 Vpp

            m_fmio.WriteString("FSKey1:FREQuency 200",true); // FSK 'hop'frequency is 200 Hz
            m_fmio.WriteString("FSKey1:INTernal:RATE 20",true); // Rate at which the output frequency 'shifts' is 20 Hz
            m_fmio.WriteString("FSKey1:SOURce INTernal",true); // Use internal signal for modulation

            m_fmio.WriteString("TRIGger1:SOURce BUS",true); // Trigger source is "bus"
            m_fmio.WriteString("FSKey1:STATe ON",true); // Turn FSK modulation on

            m_fmio.WriteString("OUTPut1 ON",true); // Turn on the instrument output

            // Trigger the function generator over the GPIB interface

            m_fmio.WriteString("*TRG",true);

	    // Close Connection
            if (m_connected)
            {
                m_session.Close();
                m_connected = false;
            }


            Console.WriteLine("Press any key to continue...");

            Console.ReadKey();

        }
    }
}
