
/****************************************************************************
	'    Copyright  2006 Agilent Technologies Inc. All rights
	'    reserved.
	'
	' You have a royalty-free right to use, modify, reproduce and distribute
	' the Sample Application Files (and/or any modified version) in any way
	' you find useful, provided that you agree that Agilent has no
	' warranty,  obligations or liability for any Sample Application Files.
	'
	' Agilent Technologies provides programming examples for illustration only,
	' This sample program assumes that you are familiar with the programming
	' language being demonstrated and the tools used to create and debug
	' procedures. Agilent support engineers can help explain the
	' functionality of Agilent software components and associated
	' commands, but they will not modify these samples to provide added
	' functionality or construct procedures to meet your specific needs.
 ****************************************************************************/

using System;
using System.Collections.Generic;
using System.Text;
using System.Threading;
using BASICFORMATTEDIOLib;
using VisaComLib;

//
// This program is an example program intended for use with
// Microsoft Visual C# and the Agilent VISA COM objects.
//
// "VISA COM 1.0 Type Library", corresponds to VISACOM.tlb
// "Agilent VISA COM Resource Manager 1.0", corresponds to AgtRM.DLL
//
// Use the statement "using VisaComLib;" to import 
// the VISA COM type library. 
//

namespace Pulse
{
    class Pulse
    {
        static void Main(string[] args)
        {
            long i;
            double time;
	        string SCPIcmd;

            AgilentRMLib.SRMClsClass m_rm = null;
            VisaComLib.FormattedIO488Class m_fmio = null;

            VisaComLib.IVisaSession m_session = null;
            bool m_connected = false;
            string m_instrument = "GPIB1::11::INSTR";

            m_rm = new AgilentRMLib.SRMClsClass();
            m_fmio = new FormattedIO488Class();

            if (!m_connected)
            {
                m_session = m_rm.Open(m_instrument, AccessMode.NO_LOCK, 4000, "");
                m_fmio.IO = (IMessage)m_session;
                m_connected = true;
            }

            // This program sets up a pulse waveshape and adjusts the edge
            // time.  It also shows the use of high and low voltage levels
            // and period.  The edge time is adjusted by 5 nsec increments.	

            /*
                ' This program commands with channel 1 of the intrument, you can change
                ' the number '1' after each command to '2' to select channel 2.
            */

           
            m_fmio.WriteString("*RST",true); // Reset the function generator
            m_fmio.IO.Clear(); // Clear errors and status registers

            m_fmio.WriteString("FUNCtion1 PULSe", true); // Select pulse waveshape

            m_fmio.WriteString("OUTPut1:LOAD 50", true); // Set the load impedance to 50 Ohms (default)
            m_fmio.WriteString("VOLTage1:LOW 0", true); // Low level = 0 V
            m_fmio.WriteString("VOLTage1:HIGH 0.75", true); // High level = .75 V

            m_fmio.WriteString("PULSe1:PERiod 1e-3", true); // 1 ms intervals
            m_fmio.WriteString("PULSe1:WIDTh 100e-6", true); // Pulse width is 100 us
            m_fmio.WriteString("PULSe1:TRANsition 10e-9", true); // Edge time is 10 ns (rise time = fall time)
            m_fmio.WriteString("OUTPut1 ON", true); // Turn on the instrument output
           
            // Vary edge by 5 nsec steps
            for (i = 0; i <= 18; i++)
            {
                time = 0.00000001 + i * 0.000000005;
                SCPIcmd = "PULSe1:TRANsition " + time.ToString();
                m_fmio.WriteString(SCPIcmd, true);
                Thread.Sleep(300); // Wait 300 msec // 
            }


            // Close Connection
            if (m_connected)
            {
                m_session.Close();
                m_connected = false;
            }
            Console.WriteLine("Press Enter to Continue...");
            Console.ReadLine();
        }

       
    }
}
