
/****************************************************************************
	'    Copyright  2006 Agilent Technologies Inc. All rights
	'    reserved.
	'
	' You have a royalty-free right to use, modify, reproduce and distribute
	' the Sample Application Files (and/or any modified version) in any way
	' you find useful, provided that you agree that Agilent has no
	' warranty,  obligations or liability for any Sample Application Files.
	'
	' Agilent Technologies provides programming examples for illustration only,
	' This sample program assumes that you are familiar with the programming
	' language being demonstrated and the tools used to create and debug
	' procedures. Agilent support engineers can help explain the
	' functionality of Agilent software components and associated
	' commands, but they will not modify these samples to provide added
	' functionality or construct procedures to meet your specific needs.
 ****************************************************************************/

using System;
using System.Collections.Generic;
using System.Text;
using BASICFORMATTEDIOLib;
using VisaComLib;

//
// This program is an example program intended for use with
// Microsoft Visual C# and the Agilent VISA COM objects.
//
// "VISA COM 1.0 Type Library", corresponds to VISACOM.tlb
// "Agilent VISA COM Resource Manager 1.0", corresponds to AgtRM.DLL
//
// Use the statement "using VisaComLib;" to import 
// the VISA COM type library. 
//

namespace PulseWidthMod
{
    class PulseWidthMod
    {
        static void Main(string[] args)
        {
            AgilentRMLib.SRMClsClass m_rm = null;
            VisaComLib.FormattedIO488Class m_fmio = null;

            VisaComLib.IVisaSession m_session = null;
            bool m_connected = false;
            string m_instrument = "GPIB1::11::INSTR";

            m_rm = new AgilentRMLib.SRMClsClass();
            m_fmio = new FormattedIO488Class();

            // Open Connection
            if (!m_connected)
            {
                m_session = m_rm.Open(m_instrument, AccessMode.NO_LOCK, 4000, "");
                m_fmio.IO = (IMessage)m_session;
                m_connected = true;
            }

            // This program uses low-level SCPI commands to configure
            // the function gnerator to output an PWM waveform.
            // The pulse is set up with a duty cycle of 35% and a depth
            // of 15%, and will vary in width from 20% to 50% with the
            // modulation.  The pulse may also be configured in time
            // units (pulse width and deviation) rather than duty cycle
            // if preferred.

            /*
            ' This program commands with channel 1 of the intrument, you can change
            ' the number '1' after each command to '2' to select channel 2.
            */

            m_fmio.WriteString("*RST", true); // Reset the function generator
            m_fmio.IO.Clear(); // Clear errors and status registers

            m_fmio.WriteString("OUTPut1:LOAD 50", true); // Output termination is 50 Ohms
            m_fmio.WriteString("FUNCtion1:SHAPe PULSe", true); // Carrier waveshape is pulse
            m_fmio.WriteString("FREQuency1 5000", true); // Carrier frequency is 5 kHz
            m_fmio.WriteString("VOLTage1:LOW 0", true); // Set parameters to 5 V TTL
            m_fmio.WriteString("VOLTage1:HIGH 5", true);
            m_fmio.WriteString("FUNCtion1:PULSe:DCYCle 35", true); // Begin with 35% duty cycle

            m_fmio.WriteString("PWM1:INTernal:FUNCtion TRIangle", true); // Modulating waveshape is triangle
            m_fmio.WriteString("PWM1:INTernal:FREQuency 2", true); // Modulation frequency is 2 Hz
            m_fmio.WriteString("PWM1:DEViation:DCYCle 15", true); // Modulation depth is 15%
            m_fmio.WriteString("PWM1:SOURce INTernal", true); // Use internal signal for modulation
            // If using an external signal for PWM, connect the signal to the rear-panel
            // BNC and use the command PWM:SOURce EXTernal

            m_fmio.WriteString("PWM1:STATe ON", true); // Turn PWM modulation on
            m_fmio.WriteString("OUTPut1 ON", true); // Turn on the instrument output

            // Close Connection
            if (m_connected)
            {
                m_session.Close();
                m_connected = false;
            }
            Console.WriteLine("Press Enter to Continue...");
            Console.ReadLine();
        }
    }
}
