/****************************************************************************
	'    Copyright  2006 Agilent Technologies Inc. All rights
	'    reserved.
	'
	' You have a royalty-free right to use, modify, reproduce and distribute
	' the Sample Application Files (and/or any modified version) in any way
	' you find useful, provided that you agree that Agilent has no
	' warranty,  obligations or liability for any Sample Application Files.
	'
	' Agilent Technologies provides programming examples for illustration only,
	' This sample program assumes that you are familiar with the programming
	' language being demonstrated and the tools used to create and debug
	' procedures. Agilent support engineers can help explain the
	' functionality of Agilent software components and associated
	' commands, but they will not modify these samples to provide added
	' functionality or construct procedures to meet your specific needs.
 ****************************************************************************/

using System;
using System.Collections.Generic;
using System.Text;
using BASICFORMATTEDIOLib;
using VisaComLib;

//
// This program is an example program intended for use with
// Microsoft Visual C# and the Agilent VISA COM objects.
//
// "VISA COM 1.0 Type Library", corresponds to VISACOM.tlb
// "Agilent VISA COM Resource Manager 1.0", corresponds to AgtRM.DLL
//
// Use the statement "using VisaComLib;" to import 
// the VISA COM type library. 
//

namespace SimpleSine
{
    class SimpleSine
    {
        static void Main(string[] args)
        {
            AgilentRMLib.SRMClsClass m_rm = null;
            VisaComLib.FormattedIO488Class m_fmio = null;

            VisaComLib.IVisaSession m_session = null;
            bool m_connected = false;
            string m_instrument = "GPIB1::11::INSTR";

            m_rm = new AgilentRMLib.SRMClsClass();
            m_fmio = new FormattedIO488Class();

            // Open Connection
            if (!m_connected)
            {
                m_session = m_rm.Open(m_instrument, AccessMode.NO_LOCK, 4000, "");
                m_fmio.IO = (IMessage)m_session;
                m_connected = true;
            }

            /*
                ' This program sets up a waveform by selecting the waveshape
                ' and adjusting the frequency, amplitude, and offset.
                ' This program shows how to commands with 2 channel by inserting
                ' the number '1' after the command to select channel 1 and the number '2'
                ' to select channel 2 in order to set up different waveform parameters.
            */


            m_fmio.WriteString("*RST", true); // Reset the function generator
            m_fmio.IO.Clear(); // Clear errors and status registers

            // Channel 1
            m_fmio.WriteString("FUNCtion1 SINusoid", true); // Select waveshape
            // Other options are SQUare, RAMP, PULSe, NOISe, DC, and USER
            m_fmio.WriteString("OUTPut1:LOAD 50", true); // Set the load impedance in Ohms (50 Ohms default)
            // May also be INFinity, as when using oscilloscope or DMM

            m_fmio.WriteString("FREQuency1 2500", true);  // Set the frequency.
            m_fmio.WriteString("VOLTage1 1.2", true); // Set the amplitude in Vpp.  Also see VOLTage:UNIT
            m_fmio.WriteString("VOLTage1:OFFSet 0.4", true); // Set the offset in Volts
            // Voltage may also be set as VOLTage:HIGH and VOLTage:LOW for low level and high level

            m_fmio.WriteString("OUTPut1 ON", true); // Turn on the instrument output



            // Channel 2
            m_fmio.WriteString("FUNCtion2 SINusoid", true); // Select waveshape
            // Other options are SQUare, RAMP, PULSe, NOISe, DC, and USER
            m_fmio.WriteString("OUTPut2:LOAD 50", true); // Set the load impedance in Ohms (50 Ohms default)
            // May also be INFinity, as when using oscilloscope or DMM

            m_fmio.WriteString("FREQuency2 5000", true);  // Set the frequency.
            m_fmio.WriteString("VOLTage2 2", true); // Set the amplitude in Vpp.  Also see VOLTage:UNIT
            m_fmio.WriteString("VOLTage2:OFFSet 1", true); // Set the offset in Volts
            // Voltage may also be set as VOLTage:HIGH and VOLTage:LOW for low level and high level

            m_fmio.WriteString("OUTPut2 ON", true); // Turn on the instrument output

            // Close Connection
            if (m_connected)
            {
                m_session.Close();
                m_connected = false;
            }
            Console.WriteLine("Press Enter to Continue...");
            Console.ReadLine();
        }
    }
}
