
/****************************************************************************
	'    Copyright  2006 Agilent Technologies Inc. All rights
	'    reserved.
	'
	' You have a royalty-free right to use, modify, reproduce and distribute
	' the Sample Application Files (and/or any modified version) in any way
	' you find useful, provided that you agree that Agilent has no
	' warranty,  obligations or liability for any Sample Application Files.
	'
	' Agilent Technologies provides programming examples for illustration only,
	' This sample program assumes that you are familiar with the programming
	' language being demonstrated and the tools used to create and debug
	' procedures. Agilent support engineers can help explain the
	' functionality of Agilent software components and associated
	' commands, but they will not modify these samples to provide added
	' functionality or construct procedures to meet your specific needs.
 ****************************************************************************/

using System;
using System.Collections.Generic;
using System.Text;
using BASICFORMATTEDIOLib;
using VisaComLib;

//
// This program is an example program intended for use with
// Microsoft Visual C# and the Agilent VISA COM objects.
//
// "VISA COM 1.0 Type Library", corresponds to VISACOM.tlb
// "Agilent VISA COM Resource Manager 1.0", corresponds to AgtRM.DLL
//
// Use the statement "using VisaComLib;" to import 
// the VISA COM type library. 
//

namespace SquareBurst
{
    class SquareBurst
    {
        static void Main(string[] args)
        {
            AgilentRMLib.SRMClsClass m_rm = null;
            VisaComLib.FormattedIO488Class m_fmio = null;

            VisaComLib.IVisaSession m_session = null;
            bool m_connected = false;
            string m_instrument = "GPIB1::11::INSTR";

            m_rm = new AgilentRMLib.SRMClsClass();
            m_fmio = new FormattedIO488Class();

            if (!m_connected)
            {
                m_session = m_rm.Open(m_instrument, AccessMode.NO_LOCK, 4000, "");
                m_fmio.IO = (IMessage)m_session;
                m_connected = true;
            }

            // This program sets up a triggered burst that outputs three
            // cycles of a square wave upon receipt of each trigger.  It
            // will also show how to adjust duty cycle and enable/disable
            // the SYNC output

            /*
            ' This program commands with channel 1 of the intrument, you can change
            ' the number '1' after each command to '2' to select channel 2.
            */

            m_fmio.WriteString("*RST", true); // Reset the function generator
            m_fmio.IO.Clear();					  // Clear errors and status registers


            m_fmio.WriteString("OUTPut1:SYNC OFF", true); // Disable the SYNC Output
            m_fmio.WriteString("FUNCtion1 SQUare", true); // Select waveshape
            m_fmio.WriteString("FUNCtion1:SQUare:DCYCle 20", true); // 20% duty cycle

            m_fmio.WriteString("OUTPut1:LOAD 50", true); // Set the load impedance to 50 Ohms (default)
            m_fmio.WriteString("VOLTage1 1", true); // Set the amplitude to 1 Vpp.
            m_fmio.WriteString("VOLTage1:OFFSet 0", true); // Set the offset to 0 V
            m_fmio.WriteString("FREQuency1 20e3", true); // Frequency at 20 kHz

            m_fmio.WriteString("TRIGger1:SOURce BUS", true); // Triggers will be received from the I/O bus
            m_fmio.WriteString("BURSt1:MODE TRIGgered", true); // Triggered burst (rather than GATed)
            m_fmio.WriteString("BURSt1:NCYCles 3", true); // 3 cycles will be output per trigger
            m_fmio.WriteString("BURSt1:STATe ON", true); // Enable burst

            m_fmio.WriteString("OUTPut1:SYNC ON", true); // Enable the SYNC Output to trigger oscilloscope
            m_fmio.WriteString("OUTPut1 ON", true); // Turn on the instrument output

            // Close Connection
            if (m_connected)
            {
                m_session.Close();
                m_connected = false;
            }
            Console.WriteLine("Press Enter to Continue...");
            Console.ReadLine();
        }
    }
}
