VERSION 5.00
Begin VB.Form frmASCIIArb 
   Caption         =   "Arbitrary Waveform - Pulse"
   ClientHeight    =   2400
   ClientLeft      =   75
   ClientTop       =   360
   ClientWidth     =   3465
   LinkTopic       =   "Form1"
   ScaleHeight     =   2400
   ScaleWidth      =   3465
   StartUpPosition =   3  'Windows Default
   Begin VB.TextBox txtIO 
      Height          =   375
      Left            =   1800
      TabIndex        =   3
      Text            =   "GPIB1::11::INSTR"
      Top             =   480
      Width           =   1575
   End
   Begin VB.TextBox txtError 
      Height          =   975
      Left            =   120
      MultiLine       =   -1  'True
      TabIndex        =   1
      Text            =   "asciiarb.frx":0000
      Top             =   1320
      Width           =   3255
   End
   Begin VB.CommandButton cmdASCIIArb 
      Caption         =   "Setup Instrument"
      Height          =   735
      Left            =   120
      TabIndex        =   0
      Top             =   120
      Width           =   1575
   End
   Begin VB.Label lblIO 
      Caption         =   "IO Address"
      Height          =   255
      Left            =   1800
      TabIndex        =   4
      Top             =   240
      Width           =   1575
   End
   Begin VB.Label lblError 
      Caption         =   "Messages"
      Height          =   375
      Left            =   120
      TabIndex        =   2
      Top             =   1080
      Width           =   2295
   End
End
Attribute VB_Name = "frmASCIIArb"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = False
Attribute VB_PredeclaredId = True
Attribute VB_Exposed = False
Option Explicit

' """""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""
'    Copyright  2006 Agilent Technologies Inc. All rights
'    reserved.
'
' You have a royalty-free right to use, modify, reproduce and distribute
' the Sample Application Files (and/or any modified version) in any way
' you find useful, provided that you agree that Agilent has no
' warranty,  obligations or liability for any Sample Application Files.
'
' Agilent Technologies provides programming examples for illustration only,
' This sample program assumes that you are familiar with the programming
' language being demonstrated and the tools used to create and debug
' procedures. Agilent support engineers can help explain the
' functionality of Agilent software components and associated
' commands, but they will not modify these samples to provide added
' functionality or construct procedures to meet your specific needs.
' """"""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""

Private Sub cmdASCIIArb_Click()

    ' This program is an example program intended for use with
    ' Microsoft Visual Basic 6.0 and the Agilent VISA COM objects.
    '
    ' To use the IO object in another Visual Basic project, set the
    ' reference to include the libraries in the Project/References menu:
    ' "VISA COM 1.0 Type Library", corresponds to VISACOM.tlb
    ' "Agilent VISA COM Resource Manager 1.0", corresponds to AgtRM.DLL
    ' "VISA COM 488.2 Formatted I/O 1.0", corresponds to the BasicFormattedIO.dll
    '
    ' Then use a statement such as "Dim Fgen As VisaComLib.FormattedIO488"
    ' to create the formatted I/O reference and use
    ' "Set Fgen = New VisaComLib.FormattedIO488" to create the actual object.

    Dim io_mgr As VisaComLib.ResourceManager
    Dim Fgen As VisaComLib.FormattedIO488

    Set io_mgr = New AgilentRMLib.SRMCls
    Set Fgen = New VisaComLib.FormattedIO488
    Set Fgen.IO = io_mgr.Open(txtIO.Text)
    
    Dim Waveform() As String
    Dim I As Integer
    Dim DataStr As String
    ReDim Waveform(1 To 4000)

    On Error GoTo MyError

    ' This program uses the arbitrary waveform function to
    ' download and output a square wave pulse with a calculated
    ' rise time and fall time.  The waveform consists of 4000
    ' points downloaded to the function generator as ASCII data.

    With Fgen
        .WriteString "*RST"                     ' Reset the function generator
        .IO.Clear                               ' Clear errors and status registers
        .IO.Timeout = 40000                     ' Set timeout to 40 seconds for long download strings
    End With

    ' Compute waveform
    
    txtError.Text = ""
    txtError.SelText = "Computing Waveform..." & vbCrLf

    For I = 1 To 5
        Waveform(I) = Str$((I - 1) / 5)         ' Set rise time (5 points)
    Next I

    For I = 6 To 205
        Waveform(I) = "1"                       ' Set pulse width (200 points)
    Next I

    For I = 206 To 210
        Waveform(I) = Str$((210 - I) / 5)       ' Set fall time (5 points)
    Next I

    For I = 211 To 4000
        Waveform(I) = "0"                       ' Set remaining points to zero
    Next I

    DataStr = Join(Waveform, ",")               ' Create string from data array

    ' Download data points to volatile memory

    txtError.SelText = "Downloading Arb..." & vbCrLf

    ' This program commands with channel 1 of the intrument, you can change
    ' the number '1' after each command to '2' to select channel 2.

    With Fgen
        .WriteString "DATA1 VOLATILE, " & DataStr
    End With

    txtError.SelText = "Download Complete" & vbCrLf

    ' Set up arbitrary waveform and output
    
    With Fgen

        .WriteString "DATA1:COPY PULSE, VOLATILE" ' Copy arb to non-volatile memory
        .WriteString "FUNCtion1:USER PULSE"       ' Select the active arb waveform
        .WriteString "FUNCtion1:SHAPe USER"       ' Output the selected arb waveform

        .WriteString "OUTPut1:LOAD 50"            ' Output termination is 50 Ohms
        .WriteString "FREQuency1 5000;VOLTage 5"  ' Output frequency is 5 kHz @ 5 Vpp
        .WriteString "OUTPut1 ON"                 ' Enable Output

    End With

    Exit Sub

MyError:

    txtError = Err.Description & vbCrLf
    Resume Next

End Sub
