VERSION 5.00
Begin VB.Form frmBinaryArb 
   Caption         =   "Arbitrary Waveform - Damped Sine"
   ClientHeight    =   2400
   ClientLeft      =   75
   ClientTop       =   360
   ClientWidth     =   3495
   LinkTopic       =   "Form1"
   ScaleHeight     =   2400
   ScaleWidth      =   3495
   StartUpPosition =   3  'Windows Default
   Begin VB.TextBox txtIO 
      Height          =   375
      Left            =   1800
      TabIndex        =   3
      Text            =   "GPIB1::11::INSTR"
      Top             =   480
      Width           =   1575
   End
   Begin VB.TextBox txtError 
      Height          =   975
      Left            =   120
      MultiLine       =   -1  'True
      TabIndex        =   1
      Text            =   "frmBinaryArb.frx":0000
      Top             =   1320
      Width           =   3255
   End
   Begin VB.CommandButton cmdBinaryArb 
      Caption         =   "Setup Instrument"
      Height          =   735
      Left            =   120
      TabIndex        =   0
      Top             =   120
      Width           =   1575
   End
   Begin VB.Label lblIO 
      Caption         =   "IO Address"
      Height          =   255
      Left            =   1800
      TabIndex        =   4
      Top             =   240
      Width           =   1575
   End
   Begin VB.Label lblError 
      Caption         =   "Messages"
      Height          =   375
      Left            =   120
      TabIndex        =   2
      Top             =   1080
      Width           =   2295
   End
End
Attribute VB_Name = "frmBinaryArb"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = False
Attribute VB_PredeclaredId = True
Attribute VB_Exposed = False
Option Explicit

' """""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""
'    Copyright  2006 Agilent Technologies Inc. All rights
'    reserved.
'
' You have a royalty-free right to use, modify, reproduce and distribute
' the Sample Application Files (and/or any modified version) in any way
' you find useful, provided that you agree that Agilent has no
' warranty,  obligations or liability for any Sample Application Files.
'
' Agilent Technologies provides programming examples for illustration only,
' This sample program assumes that you are familiar with the programming
' language being demonstrated and the tools used to create and debug
' procedures. Agilent support engineers can help explain the
' functionality of Agilent software components and associated
' commands, but they will not modify these samples to provide added
' functionality or construct procedures to meet your specific needs.
' """"""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""

Private Sub cmdBinaryArb_Click()

    ' This program is an example program intended for use with
    ' Microsoft Visual Basic 6.0 and the Agilent VISA COM objects.
    '
    ' To use the IO object in another Visual Basic project, set the
    ' reference to include the libraries in the Project/References menu:
    ' "VISA COM 1.0 Type Library", corresponds to VISACOM.tlb
    ' "Agilent VISA COM Resource Manager 1.0", corresponds to AgtRM.DLL
    ' "VISA COM 488.2 Formatted I/O 1.0", corresponds to the BasicFormattedIO.dll
    '
    ' Then use a statement such as "Dim Fgen As VisaComLib.FormattedIO488"
    ' to create the formatted I/O reference and use
    ' "Set Fgen = New VisaComLib.FormattedIO488" to create the actual object.

    Dim io_mgr As VisaComLib.ResourceManager
    Dim Fgen As VisaComLib.FormattedIO488

    Set io_mgr = New AgilentRMLib.SRMCls
    Set Fgen = New VisaComLib.FormattedIO488
    Set Fgen.IO = io_mgr.Open(txtIO.Text)
    
    Dim Waveform() As Integer
    Dim I As Long
    Dim Ncycles As Integer
    Dim Damp_factor As Single
    Dim Value As String
    Dim pi As Single
    ReDim Waveform(1 To 524288)

    On Error GoTo MyError

    ' This program shows how to down load an arbitrary waveform
    ' using binary data.  The program generates a damped sine
    ' wave using 512k (524288) points.
    
    ' This program commands with channel 1 of the intrument, you can change
    ' the number '1' after each command to '2' to select channel 2.

    With Fgen

        .IO.Timeout = 40000                                ' Set timeout to 40 seconds for long download strings
        .WriteString "*RST"                                ' Reset the function generator
        .WriteString "FORMat:BORDer NORMal"                ' Normal data bytes (send MSB first)
        .WriteString "FREQuency1 5000"                      ' Output frequency is 5 kHz
        .WriteString "OUTPut1:LOAD 50"                      ' Output termination is 50 Ohms
        .WriteString "VOLTage1 5"                           ' Output amplitude is 5 Vpp

    End With

    txtError.Text = ""
    txtError.SelText = "Computing Waveform..." & vbCrLf

    Ncycles = 10                                           ' Define number of sinewave cycles
    Damp_factor = -5                                       ' Define damping factor
    pi = 3.14159                                           ' Define pi

    '
    ' Calculate data points
    '

    For I = 1 To 524288
        If I < 524000 Then
            Waveform(I) = (Sin(2 * pi * Ncycles * I / 524000) * 2047)
            Waveform(I) = Waveform(I) * Exp(Damp_factor * I / 524000)
        Else
            Waveform(I) = 0
        End If
    Next I

    ' Download data points to volatile memory from array

    txtError.SelText = "Downloading Arb..." & vbCrLf
    With Fgen
        .WriteIEEEBlock "Data1:Dac Volatile,", Waveform
        .WriteString "*OPC?"
        Value = .ReadString
    End With
    txtError.SelText = "Download Complete" & vbCrLf

    With Fgen

        .WriteString "DATA1:COPY DAMP_SINE, VOLATILE"       ' Copy arb to non-volatile memory
        .WriteString "FUNCtion1:USER DAMP_SINE"             ' Select the active arb waveform
        .WriteString "FUNCtion1:SHAPe USER"                 ' Output the selected arb waveform
        .WriteString "OUTPut1 ON"                           ' Enable output

    End With

    Exit Sub

MyError:

    txtError = Err.Description & vbCrLf
    Resume Next

End Sub

