
/****************************************************************************
	'    Copyright  2006 Agilent Technologies Inc. All rights
	'    reserved.
	'
	' You have a royalty-free right to use, modify, reproduce and distribute
	' the Sample Application Files (and/or any modified version) in any way
	' you find useful, provided that you agree that Agilent has no
	' warranty,  obligations or liability for any Sample Application Files.
	'
	' Agilent Technologies provides programming examples for illustration only,
	' This sample program assumes that you are familiar with the programming
	' language being demonstrated and the tools used to create and debug
	' procedures. Agilent support engineers can help explain the
	' functionality of Agilent software components and associated
	' commands, but they will not modify these samples to provide added
	' functionality or construct procedures to meet your specific needs.
 ****************************************************************************/

#include <string.h>
#include <stdlib.h>
#include <stdio.h>
#include <visa.h>

#define	CHECK(func)	\
do {\
    ViStatus _s = (func);\
    if (_s < 0)\
    {\
	fprintf(stderr, "Error: %s returned %d\n", #func, _s);\
	exit(0);\
    }\
} while (0)

/* Specify the default address */
#define DEFAULT_LOGICAL_ADDRESS "GPIB1::11::INSTR"


void main()
{
	ViSession   viDefaultRM, Instrument;
	ViRsrc      TxtAddress = DEFAULT_LOGICAL_ADDRESS;
	ViUInt32	actual;
	char SCPIcmd[10000];
	unsigned short i;

	CHECK(viOpenDefaultRM(&viDefaultRM));
	CHECK(viOpen(viDefaultRM, TxtAddress, VI_NULL, VI_NULL, &Instrument));

	/* Specify long seconds timeout for waveform download */
	CHECK(viSetAttribute(Instrument, VI_ATTR_TMO_VALUE, 40000));
	
	/*
        ' This program is an example program intended for use with
		' Microsoft Visual C++ 2005 and requires the VISA installed.
	 */
		
	/*
		' This program uses the arbitrary waveform function to
		' download and output a square wave pulse with a calculated
		' rise time and fall time.  The waveform consists of 4000
		' points downloaded to the function generator as ASCII data.
  
		' This program commands with channel 1 of the intrument, you can change
		' the number '1' after each command to '2' to select channel 2.
	 */
		
	strcpy(SCPIcmd,"*RST\n");  /* Reset the function generator */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
	strcpy(SCPIcmd,"*CLS\n");  /* Clear errors and status registers */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));

	/* Compute waveform */
		
	fprintf(stderr, "Computing Waveform...\n");
		
	strcpy(SCPIcmd, "DATA1 VOLATILE");
	for(i = 1; i <= 5; i++)        /* Set rise time (5 points) */
		sprintf(SCPIcmd, "%s,%3.1f", SCPIcmd, (double)(i - 1)/5);

	for(i = 6; i <= 205; i++)
		strcat(SCPIcmd, ",1");     /* Set pulse width (200 points) */

	for(i = 206; i <= 210; i++)    /* Set fall time (5 points) */
		sprintf(SCPIcmd, "%s,%3.1f", SCPIcmd, (double)(210 - i)/5);

	for(i = 211; i <= 4000; i++)
		strcat(SCPIcmd, ",0");     /* Set remaining points to zero */

	strcat(SCPIcmd,"\n");

		
	/* Download data points to volatile memory */
		
	fprintf(stderr,"Downloading Arb...\n");
		
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
		
	fprintf(stderr,"Download Complete\n");
		
	/* Set up arbitrary waveform and output */
	
	strcpy(SCPIcmd,"DATA1:COPY PULSE, VOLATILE\n");  /* Copy arb to non-volatile memory */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
	strcpy(SCPIcmd, "FUNCtion1:USER PULSE\n"); /*  Select the active arb waveform */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
	strcpy(SCPIcmd, "FUNCtion1:SHAPe USER\n"); /* Output the selected arb waveform */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
		
	strcpy(SCPIcmd, "OUTPut1:LOAD 50\n"); /* Output termination is 50 Ohms */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
	strcpy(SCPIcmd, "FREQuency1 5000;VOLTage 5\n"); /* Output frequency is 5 kHz @ 5 Vpp */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
	strcpy(SCPIcmd, "OUTPut1 ON\n"); /* Enable output */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
		
	CHECK(viClose(Instrument));
	CHECK(viClose(viDefaultRM));
}
