
/****************************************************************************
	'    Copyright  2006 Agilent Technologies Inc. All rights
	'    reserved.
	'
	' You have a royalty-free right to use, modify, reproduce and distribute
	' the Sample Application Files (and/or any modified version) in any way
	' you find useful, provided that you agree that Agilent has no
	' warranty,  obligations or liability for any Sample Application Files.
	'
	' Agilent Technologies provides programming examples for illustration only,
	' This sample program assumes that you are familiar with the programming
	' language being demonstrated and the tools used to create and debug
	' procedures. Agilent support engineers can help explain the
	' functionality of Agilent software components and associated
	' commands, but they will not modify these samples to provide added
	' functionality or construct procedures to meet your specific needs.
 ****************************************************************************/

#include <string.h>
#include <stdlib.h>
#include <stdio.h>
#include <math.h>
#include <visa.h>

#define	CHECK(func)	\
do {\
    ViStatus _s = (func);\
    if (_s < 0)\
    {\
	fprintf(stderr, "Error: %s returned %d\n", #func, _s);\
	exit(0);\
    }\
} while (0)

/* Specify the default address */
#define DEFAULT_LOGICAL_ADDRESS "GPIB1::11::INSTR"


void main()
{
	ViSession   viDefaultRM, Instrument;
	ViRsrc      TxtAddress = DEFAULT_LOGICAL_ADDRESS;
	ViUInt32	actual;
	char SCPIcmd[40000];

	short  Waveform[16000];
	long   Ncycles = 10;     /* Define number of sinewave cycles */
	double Damp_factor = -5; /* Define damping factor */
	double pi = 3.14159;     /* Define pi */
	long   i;
	char   replyString[256];


	CHECK(viOpenDefaultRM(&viDefaultRM));
	CHECK(viOpen(viDefaultRM, TxtAddress, VI_NULL, VI_NULL, &Instrument));
	CHECK(viSetAttribute(Instrument, VI_ATTR_TMO_VALUE, 40000));
	
	/*
        ' This program is an example program intended for use with
		' Microsoft Visual C++ 2005 and requires the VISA installed.
	 */
		
	/*
		' This program shows how to down load an arbitrary waveform
		' using binary data.  The program generates a damped sine
		' wave using 16,000 points.

  
		' This program commands with channel 1 of the intrument, you can change
		' the number '1' after each command to '2' to select channel 2.
	 */


	strcpy(SCPIcmd, "*RST\n");               /* Reset the function generator */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
	strcpy(SCPIcmd, "FORMat:BORDer SWAP\n"); /* Swap data bytes (send LSB first) */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
	strcpy(SCPIcmd, "FREQuency1 5000\n");     /* Output frequency is 5 kHz */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
	strcpy(SCPIcmd, "OUTPut1:LOAD 50\n");     /* Output termination is 50 Ohms */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
	strcpy(SCPIcmd, "VOLTage1 5\n");          /* Output amplitude is 5 Vpp */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
	

	fprintf(stderr, "Computing Waveform...\n");
		
		
	/* Calculate data points */
				
	for (i = 1; i<= 16000; i++)
	{
		if(i < 14000)
		{
			Waveform[i-1] = (short)(sin(2.0 * pi * (double)Ncycles * (double)i / 14000) * 2047
				* exp(Damp_factor * (double)i / 14000) + 0.5);
		}
		else
		{
			Waveform[i-1] = 0;
		}
	}
		
	/* Download data points to volatile memory from array */
		
	fprintf(stderr, "Downloading Arb...\n");
		
	/*Write IEEEBlock "DATA[1|2]:DAC VOLATILE,", IEEE 488.2 Binary block */
	strcpy(SCPIcmd, "DATA1:DAC VOLATILE, #532000");
	memcpy((void *)&SCPIcmd[27],(const void *)Waveform, 32000);
	CHECK(viWrite(Instrument, SCPIcmd, 32027, &actual));
	
	strcpy(SCPIcmd, ";*OPC?\n");
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
	CHECK(viRead(Instrument, replyString, 255, &actual));
	replyString[actual] = '\0';
		
	fprintf(stderr, "Download Complete\n");
		
	strcpy(SCPIcmd, "DATA1:COPY DAMP_SIN, VOLATILE\n"); /* Copy arb to non-volatile memory */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
	strcpy(SCPIcmd, "FUNCtion1:USER DAMP_SIN\n"); /* Select the active arb waveform */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
	strcpy(SCPIcmd, "FUNCtion1:SHAPe USER\n");    /* Output the selected arb waveform */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
	strcpy(SCPIcmd, "OUTPut1 ON\n");              /* Enable output */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
	
	CHECK(viClose(Instrument));
	CHECK(viClose(viDefaultRM));
}
