
/****************************************************************************
	'    Copyright  2006 Agilent Technologies Inc. All rights
	'    reserved.
	'
	' You have a royalty-free right to use, modify, reproduce and distribute
	' the Sample Application Files (and/or any modified version) in any way
	' you find useful, provided that you agree that Agilent has no
	' warranty,  obligations or liability for any Sample Application Files.
	'
	' Agilent Technologies provides programming examples for illustration only,
	' This sample program assumes that you are familiar with the programming
	' language being demonstrated and the tools used to create and debug
	' procedures. Agilent support engineers can help explain the
	' functionality of Agilent software components and associated
	' commands, but they will not modify these samples to provide added
	' functionality or construct procedures to meet your specific needs.
 ****************************************************************************/

#include <string.h>
#include <stdlib.h>
#include <stdio.h>
#include <visa.h>

#define	CHECK(func)	\
do {\
    ViStatus _s = (func);\
    if (_s < 0)\
    {\
	fprintf(stderr, "Error: %s returned %d\n", #func, _s);\
	exit(0);\
    }\
} while (0)

/* Specify the default address */
#define DEFAULT_LOGICAL_ADDRESS "GPIB1::11::INSTR"


void main()
{
	ViSession   viDefaultRM, Instrument;
	ViRsrc      TxtAddress = DEFAULT_LOGICAL_ADDRESS;
	ViUInt32	actual;
	char SCPIcmd[128];

	CHECK(viOpenDefaultRM(&viDefaultRM));
	CHECK(viOpen(viDefaultRM, TxtAddress, VI_NULL, 2500, &Instrument));
	
	/*
        ' This program is an example program intended for use with
 		' Microsoft Visual C++ 2005 and requires the VISA installed
	 */
		
	/*
		' This program uses low-level SCPI commands to configure
		' the function gnerator to output an AM waveform.
		' This program also shows how to use "state storage" to
		' store the instrument configuration in memory.

  
		' This program commands with channel 1 of the intrument, you can change
		' the number '1' after each command to '2' to select channel 2.
	 */
		
	strcpy(SCPIcmd,"*RST\n");  /* Reset the function generator */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));


	strcpy(SCPIcmd, "OUTPut1:LOAD 50\n");  /* Output termination is 50 Ohms */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));		
	strcpy(SCPIcmd, "FUNCtion1:SHAPe SINusoid\n");        /* Carrier waveshape is sine wave*/
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
	strcpy(SCPIcmd, "FREQuency1 5000;VOLTage 5\n");       /* Carrier frequency is 5 kHz @ 5 Vpp */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
	strcpy(SCPIcmd, "AM1:INTernal:FUNCtion SINusoid\n");  /* Modulating waveshape is sine */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
	strcpy(SCPIcmd, "AM1:INTernal:FREQuency 200\n");     /* Modulation frequency is 200 Hz */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
	strcpy(SCPIcmd, "AM1:DEPTh 80\n");     /* Modulation depth is 80% */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
	strcpy(SCPIcmd, "AM1:STATe ON\n");     /* Turn AM modulation on */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
		
	strcpy(SCPIcmd, "OUTPut1 ON\n");  /* Turn on the instrument output */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
	strcpy(SCPIcmd, "*SAV 1\n");     /* Store state in memory location 1 */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
	
	/* Use the "*RCL 1" command to recall the stored state */

	CHECK(viClose(Instrument));
	CHECK(viClose(viDefaultRM));
}
