
/****************************************************************************
	'    Copyright  2006 Agilent Technologies Inc. All rights
	'    reserved.
	'
	' You have a royalty-free right to use, modify, reproduce and distribute
	' the Sample Application Files (and/or any modified version) in any way
	' you find useful, provided that you agree that Agilent has no
	' warranty,  obligations or liability for any Sample Application Files.
	'
	' Agilent Technologies provides programming examples for illustration only,
	' This sample program assumes that you are familiar with the programming
	' language being demonstrated and the tools used to create and debug
	' procedures. Agilent support engineers can help explain the
	' functionality of Agilent software components and associated
	' commands, but they will not modify these samples to provide added
	' functionality or construct procedures to meet your specific needs.
 ****************************************************************************/

#include <string.h>
#include <stdlib.h>
#include <stdio.h>
#include <time.h>
#include <visa.h>

#define	CHECK(func)	\
do {\
    ViStatus _s = (func);\
    if (_s < 0)\
    {\
	fprintf(stderr, "Error: %s returned %d\n", #func, _s);\
	exit(0);\
    }\
} while (0)

/* Specify the default address */
#define DEFAULT_LOGICAL_ADDRESS "GPIB1::11::INSTR"

void sleep( clock_t wait );

void main()
{
	ViSession   viDefaultRM, Instrument;
	ViRsrc      TxtAddress = DEFAULT_LOGICAL_ADDRESS;
	ViUInt32	actual;
	char SCPIcmd[128];
	long i;

	CHECK(viOpenDefaultRM(&viDefaultRM));
	CHECK(viOpen(viDefaultRM, TxtAddress, VI_NULL, 2500, &Instrument));
	
	/*
	 * This program is an example program intended for use with
	 * Microsoft Visual C++ 2005 and requires the VISA installed.
	 */
		
	/*
	 * This program sets up a pulse waveshape and adjusts the edge
	 * time.  It also shows the use of high and low voltage levels
	 * and period.  The edge time is adjusted by 5 nsec increments.

  
	' This program commands with channel 1 of the intrument, you can change
	' the number '1' after each command to '2' to select channel 2.
	 */
		
	strcpy(SCPIcmd,"*RST\n");  /* Reset the function generator */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
	strcpy(SCPIcmd,"*CLS\n");  /* Clear errors and status registers */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
		
	strcpy(SCPIcmd,"FUNCtion1 PULSe\n");  /* Select pulse waveshape */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));

	strcpy(SCPIcmd, "OUTPut1:LOAD 50\n"); /* Set the load impedance in Ohms (50 Ohms default) */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
	strcpy(SCPIcmd, "VOLTage1:LOW 0;:VOLTage:HIGH 0.75\n");  /* Low level = 0 V, High level = .75 V */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
		
	strcpy(SCPIcmd, "PULSe1:PERiod 1e-3\n");  /* 1 ms intervals */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
	strcpy(SCPIcmd, "PULSe1:WIDTh 100e-6\n");  /* Pulse width is 100 us */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
	strcpy(SCPIcmd, "PULSe1:TRANsition 10e-9\n");  /* Edge time is 10 ns (rise time = fall time) */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
	strcpy(SCPIcmd, "OUTPut1 ON\n");  /* Turn on the instrument output */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
		
	for (i=0; i<=18; i++)
	{
		sprintf(SCPIcmd, "PULSe1:TRANsition %.10f\n", 0.00000001 + i * 0.000000005); /* Vary edge by 5 nsec steps */
		CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
		sleep((clock_t)(0.3*CLOCKS_PER_SEC)); /* Wait 300 msec */
	}

	CHECK(viClose(Instrument));
	CHECK(viClose(viDefaultRM));
}

/* Pauses for a specified number of milliseconds. */
void sleep( clock_t wait )
{
   clock_t goal;
   goal = wait + clock();
   while( goal > clock() )
      ;
}
