
/****************************************************************************
	'    Copyright  2006 Agilent Technologies Inc. All rights
	'    reserved.
	'
	' You have a royalty-free right to use, modify, reproduce and distribute
	' the Sample Application Files (and/or any modified version) in any way
	' you find useful, provided that you agree that Agilent has no
	' warranty,  obligations or liability for any Sample Application Files.
	'
	' Agilent Technologies provides programming examples for illustration only,
	' This sample program assumes that you are familiar with the programming
	' language being demonstrated and the tools used to create and debug
	' procedures. Agilent support engineers can help explain the
	' functionality of Agilent software components and associated
	' commands, but they will not modify these samples to provide added
	' functionality or construct procedures to meet your specific needs.
 ****************************************************************************/

#include <string.h>
#include <stdlib.h>
#include <stdio.h>
#include <visa.h>

#define	CHECK(func)	\
do {\
    ViStatus _s = (func);\
    if (_s < 0)\
    {\
	fprintf(stderr, "Error: %s returned %d\n", #func, _s);\
	exit(0);\
    }\
} while (0)

/* Specify the default address */
#define DEFAULT_LOGICAL_ADDRESS "GPIB1::11::INSTR"


void main()
{
	ViSession   viDefaultRM, Instrument;
	ViRsrc      TxtAddress = DEFAULT_LOGICAL_ADDRESS;
	ViUInt32	actual;
	char SCPIcmd[128];

	CHECK(viOpenDefaultRM(&viDefaultRM));
	CHECK(viOpen(viDefaultRM, TxtAddress, VI_NULL, 2500, &Instrument));
	
	/*
	 * This example program is adapted for Microsoft
	 * Visual C++ 2005 and requires the VISA installed
	 */
		
	/*
	 * This program uses low-level SCPI commands to configure
	 * the function gnerator to output an PWM waveform.
	 * The pulse is set up with a duty cycle of 35% and a depth
	 * of 15%, and will vary in width from 20% to 50% with the
	 * modulation.  The pulse may also be configured in time
	 * units (pulse width and deviation) rather than duty cycle 
	 * if preferred.

  
	' This program commands with channel 1 of the intrument, you can change
	' the number '1' after each command to '2' to select channel 2.
	 */
		
	strcpy(SCPIcmd,"*RST\n");                           /* Reset the function generator */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));

	strcpy(SCPIcmd, "OUTPut1:LOAD 50\n");                /* Output termination is 50 Ohms */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
	strcpy(SCPIcmd, "FUNCtion1:SHAPe PULSe\n");          /* Carrier waveshape is pulse */
    CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
    strcpy(SCPIcmd,"FREQuency1 5000\n");                 /* Carrier frequency is 5 kHz */
    CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
    strcpy(SCPIcmd, "VOLTage1:LOW 0\n");                 /* Set parameters to 5 V TTL */
    CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
    strcpy(SCPIcmd,"VOLTage1:HIGH 5\n");
    CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
    strcpy(SCPIcmd, "FUNCtion1:PULSe:DCYCle 35\n");     /* Begin with 35% duty cycle */
    CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));

    strcpy(SCPIcmd,"PWM1:INTernal:FUNCtion TRIangle\n"); /* Modulating waveshape is triangle */
    CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
    strcpy(SCPIcmd,"PWM1:INTernal:FREQuency 2\n");       /* Modulation frequency is 2 Hz */
    CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
    strcpy(SCPIcmd,"PWM1:DEViation:DCYCle 15\n");        /* Modulation depth is 15% */
    CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
    strcpy(SCPIcmd, "PWM1:SOURce INTernal\n");           /* Use internal signal for modulation */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
    /*  
	 * If using an external signal for PWM, connect the signal to the rear-panel
     * BNC and use the command PWM:SOURce EXTernal
	 */
	strcpy(SCPIcmd, "PWM1:STATe ON\n");                  /* Turn PWM modulation on */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));

	strcpy(SCPIcmd, "OUTPut1 ON\n");                      /* Turn on the instrument output */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));

	CHECK(viClose(Instrument));
	CHECK(viClose(viDefaultRM));
}
