
/****************************************************************************
	'    Copyright  2006 Agilent Technologies Inc. All rights
	'    reserved.
	'
	' You have a royalty-free right to use, modify, reproduce and distribute
	' the Sample Application Files (and/or any modified version) in any way
	' you find useful, provided that you agree that Agilent has no
	' warranty,  obligations or liability for any Sample Application Files.
	'
	' Agilent Technologies provides programming examples for illustration only,
	' This sample program assumes that you are familiar with the programming
	' language being demonstrated and the tools used to create and debug
	' procedures. Agilent support engineers can help explain the
	' functionality of Agilent software components and associated
	' commands, but they will not modify these samples to provide added
	' functionality or construct procedures to meet your specific needs.
 ****************************************************************************/

#include <string.h>
#include <stdlib.h>
#include <stdio.h>
#include <visa.h>

#define	CHECK(func)	\
do {\
    ViStatus _s = (func);\
    if (_s < 0)\
    {\
	fprintf(stderr, "Error: %s returned %d\n", #func, _s);\
	exit(0);\
    }\
} while (0)

/* Specify the default address */
#define DEFAULT_LOGICAL_ADDRESS "GPIB1::11::INSTR"


void main()
{
	ViSession   viDefaultRM, Instrument;
	ViRsrc      TxtAddress = DEFAULT_LOGICAL_ADDRESS;
	ViUInt32	actual;
	char SCPIcmd[128];

	CHECK(viOpenDefaultRM(&viDefaultRM));
	CHECK(viOpen(viDefaultRM, TxtAddress, VI_NULL, 2500, &Instrument));
	
	/*
		' This program is an example program intended for use with
		' Microsoft Visual C++ 2005 and requires the VISA installed
	 */
		
	/*
		' This program sets up a waveform by selecting the waveshape
		' and adjusting the frequency, amplitude, and offset.
    
		' This program shows how to commands with 2 channel by inserting
		' the number '1' after the command to select channel 1 and the number '2'
		' to select channel 2 in order to set up different waveform parameters.

	 */
		
	strcpy(SCPIcmd,"*RST\n");  /* Reset the function generator */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
	strcpy(SCPIcmd,"*CLS\n");  /* Clear errors and status registers */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
	
	// Channel 1
	strcpy(SCPIcmd,"FUNCtion1 SINusoid\n");  /* Select waveshape */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
	/* Other options are SQUare, RAMP, PULSe, NOISe, DC, and USER */
	
	strcpy(SCPIcmd, "OUTPut1:LOAD 50\n"); /* Set the load impedance in Ohms (50 Ohms default) */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
	/* May also be INFinity, as when using oscilloscope or DMM */
	
	strcpy(SCPIcmd, "FREQuency1 2500\n"); /* Set the frequency */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));

	strcpy(SCPIcmd, "VOLTage1 1.2\n");  /*Set the amplitude in Vpp.  Also see VOLTage:UNIT */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
	
	strcpy(SCPIcmd, "VOLTage1:OFFSet 0.4\n"); /* Set the offset in Volts */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
	/* Voltage may also be set as VOLTage:HIGH and VOLTage:LOW for low level and high level */
		
	strcpy(SCPIcmd, "OUTPut1 ON\n");  /* Turn on the instrument output */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));


	// Channel 2
	strcpy(SCPIcmd,"FUNCtion2 SINusoid\n");  /* Select waveshape */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
	/* Other options are SQUare, RAMP, PULSe, NOISe, DC, and USER */
	
	strcpy(SCPIcmd, "OUTPut2:LOAD 50\n"); /* Set the load impedance in Ohms (50 Ohms default) */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
	/* May also be INFinity, as when using oscilloscope or DMM */
	
	strcpy(SCPIcmd, "FREQuency2 5000\n"); /* Set the frequency */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));

	strcpy(SCPIcmd, "VOLTage2 2\n");  /*Set the amplitude in Vpp.  Also see VOLTage:UNIT */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
	
	strcpy(SCPIcmd, "VOLTage2:OFFSet 1\n"); /* Set the offset in Volts */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
	/* Voltage may also be set as VOLTage:HIGH and VOLTage:LOW for low level and high level */
		
	strcpy(SCPIcmd, "OUTPut2 ON\n");  /* Turn on the instrument output */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
		
	CHECK(viClose(Instrument));
	CHECK(viClose(viDefaultRM));
}
