
/****************************************************************************
	'    Copyright  2006 Agilent Technologies Inc. All rights
	'    reserved.
	'
	' You have a royalty-free right to use, modify, reproduce and distribute
	' the Sample Application Files (and/or any modified version) in any way
	' you find useful, provided that you agree that Agilent has no
	' warranty,  obligations or liability for any Sample Application Files.
	'
	' Agilent Technologies provides programming examples for illustration only,
	' This sample program assumes that you are familiar with the programming
	' language being demonstrated and the tools used to create and debug
	' procedures. Agilent support engineers can help explain the
	' functionality of Agilent software components and associated
	' commands, but they will not modify these samples to provide added
	' functionality or construct procedures to meet your specific needs.
 ****************************************************************************/

#include <stdio.h>
#include <math.h>

#define	CHECK(func)	\
do {\
    long _s = (func);\
    if (_s <= 0)\
    {\
	fprintf(stderr, "Error: %s returned %d\n", #func, _s);\
	exit(0);\
    }\
} while (0)

// Specify the default address
#define DEFAULT_LOGICAL_ADDRESS OLESTR("GPIB1::11::INSTR")

#import "visacom.tlb" no_namespace
#import "agtrm.dll" no_namespace

void main()
{
	BSTR     TxtAddress = DEFAULT_LOGICAL_ADDRESS;
	long   Ncycles = 10;     // Define number of sinewave cycles
	double Damp_factor = -5; // Define damping factor
	double pi = 3.14159;     // Define pi
	long   i;

	//
	// This program is an example program intended for use with
	// Microsoft Visual C++ 2005 and the Agilent VISA COM objects.
	//
	// "VISA COM 1.0 Type Library", corresponds to VISACOM.tlb
	// "Agilent VISA COM Resource Manager 1.0", corresponds to AgtRM.DLL
	//
	// Use the statement "#import "VisaCom.tlb" no_namespace" to import 
	// the VISA COM type library. 
    // Create a variable of type IResourceManagerPtr to hold the reference to the object.  
	// To create the object, use  "io_mgr.CreateInstance( __uuidof(SRMCls) )".
	//

	IResourceManagerPtr io_mgr;
    IMessagePtr Fgen;
	IFormattedIO488Ptr fmio;


    CoInitialize(NULL);

    io_mgr.CreateInstance(__uuidof(SRMCls));
	fmio.CreateInstance(__uuidof(FormattedIO488));

	Fgen = io_mgr->Open(TxtAddress, NO_LOCK, 2000, "");
	fmio->IO = Fgen;
		
    // This program shows how to down load an arbitrary waveform
	// using binary data.  The program generates a damped sine
	// wave using 512k (524288) points.		
	
	/*
		' This program commands with channel 1 of the intrument, you can change
		' the number '1' after each command to '2' to select channel 2.
	*/

	Fgen->Timeout = 40000;			  // Set 40 seconds timeout.
	CHECK(Fgen->WriteString("*RST")); // Reset the function generator
	Fgen->Clear();					  // Clear errors and status registers
			
    CHECK(Fgen->WriteString("FORMat:BORDer NORMal")); // Normal order data bytes (send MSB first)
    CHECK(Fgen->WriteString("FREQuency1 5000"));		// Output frequency is 5 kHz
    CHECK(Fgen->WriteString("OUTPut1:LOAD 50"));		// Output termination is 50 Ohms
    CHECK(Fgen->WriteString("VOLTage1 5"));			// Output amplitude is 5 Vpp


    //
    // Calculate data points
    //

	VARIANT Val;
	VariantInit(&Val);
	Val.vt = VT_ARRAY | VT_I2;

	SAFEARRAY *psa;

	// Build a SafeArray of integer values.
	SAFEARRAYBOUND bounds = {524288, 0};
	psa = SafeArrayCreate (VT_I2, 1, &bounds);

	// Populate the safearray
	SHORT* Waveform;
	SafeArrayAccessData(psa, (void**) &Waveform);

	for (i = 1; i<= 524288; i++)
	{
		if(i < 524000)
		{
			Waveform[i-1] = (short)(sin(2.0 * pi * (double)Ncycles * (double)i / 524000) * 2047
				* exp(Damp_factor * (double)i / 524000) + 0.5);
		}
		else
		{
			Waveform[i-1] = 0;
		}
	}
	
	SafeArrayUnaccessData(psa);
	Val.parray = psa;

    // Download data points to volatile memory from array //
	fprintf(stderr, "Downloading Arb...\n");
		
	// Write IEEEBlock "DATA:DAC VOLATILE,", IEEE 488.2 Binary block
	fmio->WriteIEEEBlock("DATA1:DAC VOLATILE,", Val, VARIANT_TRUE);   

    fmio->WriteString("*OPC?", VARIANT_TRUE); 
    fmio->ReadString();

	fprintf(stderr, "Download Complete\n");

    CHECK(Fgen->WriteString("DATA1:COPY DAMP_SIN, VOLATILE"));	// Copy arb to non-volatile memory
    CHECK(Fgen->WriteString("FUNCtion1:USER DAMP_SIN"));		// Select the active arb waveform
    CHECK(Fgen->WriteString("FUNCtion1:SHAPe USER"));			// Output the selected arb waveform
    CHECK(Fgen->WriteString("OUTPut1 ON"));						// Enable output
}


