
/****************************************************************************
	'    Copyright  2006 Agilent Technologies Inc. All rights
	'    reserved.
	'
	' You have a royalty-free right to use, modify, reproduce and distribute
	' the Sample Application Files (and/or any modified version) in any way
	' you find useful, provided that you agree that Agilent has no
	' warranty,  obligations or liability for any Sample Application Files.
	'
	' Agilent Technologies provides programming examples for illustration only,
	' This sample program assumes that you are familiar with the programming
	' language being demonstrated and the tools used to create and debug
	' procedures. Agilent support engineers can help explain the
	' functionality of Agilent software components and associated
	' commands, but they will not modify these samples to provide added
	' functionality or construct procedures to meet your specific needs.
 ****************************************************************************/

#include <stdio.h>

#define	CHECK(func)	\
do {\
    long _s = (func);\
    if (_s <= 0)\
    {\
	fprintf(stderr, "Error: %s returned %d\n", #func, _s);\
	exit(0);\
    }\
} while (0)

// Specify the default address
#define DEFAULT_LOGICAL_ADDRESS OLESTR("GPIB1::11::INSTR")

#import "visacom.tlb" no_namespace
#import "agtrm.dll" no_namespace

void main()
{
	BSTR     TxtAddress = DEFAULT_LOGICAL_ADDRESS;

	//
	// This program is an example program intended for use with
	// Microsoft Visual C++ 2005 and the Agilent VISA COM objects.
	//
	// "VISA COM 1.0 Type Library", corresponds to VISACOM.tlb
	// "Agilent VISA COM Resource Manager 1.0", corresponds to AgtRM.DLL
	//
	// Use the statement "#import "VisaCom.tlb" no_namespace" to import 
	// the VISA COM type library. 
    // Create a variable of type IResourceManagerPtr to hold the reference to the object.  
	// To create the object, use  "io_mgr.CreateInstance( __uuidof(SRMCls) )".
	//

	IResourceManagerPtr io_mgr;
    IMessagePtr Fgen;

    CoInitialize(NULL);

    io_mgr.CreateInstance(__uuidof(SRMCls));

	Fgen = io_mgr->Open(TxtAddress, NO_LOCK, 2000, "");
		
    // This program sets up a linear sweep using a sinusoid
    // waveform.  It sets the start and stop frequency and sweep
    // time.	
			
	/*
    ' This program commands with channel 1 of the intrument, you can change
    ' the number '1' after each command to '2' to select channel 2.
	*/

	CHECK(Fgen->WriteString("*RST")); // Reset the function generator
	Fgen->Clear(); // Clear errors and status registers
			
    CHECK(Fgen->WriteString("FUNCtion1 SINusoid")); // Select waveshape

    CHECK(Fgen->WriteString("OUTPut1:LOAD 50")); // Set the load impedance to 50 Ohms (default)
    CHECK(Fgen->WriteString("VOLTage1 1")); // Set the amplitude to 1 Vpp.

    CHECK(Fgen->WriteString("SWEep1:SPACing LINear")); // Set Linear or LOGarithmic spacing
    CHECK(Fgen->WriteString("SWEep1:TIME 1")); // Sweep time is 1 second
    CHECK(Fgen->WriteString("FREQuency1:STARt 100")); // Start frequency is 100 Hz
    CHECK(Fgen->WriteString("FREQuency1:STOP 20e3")); // Stop frequency is 20 kHz


    CHECK(Fgen->WriteString("OUTPut1 ON")); // Turn on the instrument output
    CHECK(Fgen->WriteString("SWEep1:STATe ON")); // Turn sweep on

}
