
/****************************************************************************
	'    Copyright  2006 Agilent Technologies Inc. All rights
	'    reserved.
	'
	' You have a royalty-free right to use, modify, reproduce and distribute
	' the Sample Application Files (and/or any modified version) in any way
	' you find useful, provided that you agree that Agilent has no
	' warranty,  obligations or liability for any Sample Application Files.
	'
	' Agilent Technologies provides programming examples for illustration only,
	' This sample program assumes that you are familiar with the programming
	' language being demonstrated and the tools used to create and debug
	' procedures. Agilent support engineers can help explain the
	' functionality of Agilent software components and associated
	' commands, but they will not modify these samples to provide added
	' functionality or construct procedures to meet your specific needs.
 ****************************************************************************/

#include <stdio.h>

#define	CHECK(func)	\
do {\
    long _s = (func);\
    if (_s <= 0)\
    {\
	fprintf(stderr, "Error: %s returned %d\n", #func, _s);\
	exit(0);\
    }\
} while (0)

// Specify the default address
#define DEFAULT_LOGICAL_ADDRESS OLESTR("GPIB1::11::INSTR")

#import "visacom.tlb" no_namespace
#import "agtrm.dll" no_namespace

void main()
{
	BSTR     TxtAddress = DEFAULT_LOGICAL_ADDRESS;

	//
	// This program is an example program intended for use with
	// Microsoft Visual C++ 2005 and the Agilent VISA COM objects.
	//
	// "VISA COM 1.0 Type Library", corresponds to VISACOM.tlb
	// "Agilent VISA COM Resource Manager 1.0", corresponds to AgtRM.DLL
	//
	// Use the statement "#import "VisaCom.tlb" no_namespace" to import 
	// the VISA COM type library. 
    // Create a variable of type IResourceManagerPtr to hold the reference to the object.  
	// To create the object, use  "io_mgr.CreateInstance( __uuidof(SRMCls) )".
	//

	IResourceManagerPtr io_mgr;
    IMessagePtr Fgen;

    CoInitialize(NULL);

    io_mgr.CreateInstance(__uuidof(SRMCls));

	Fgen = io_mgr->Open(TxtAddress, NO_LOCK, 2000, "");
		
    // This program uses low-level SCPI commands to configure
    // the function gnerator to output an AM waveform.
    // This program also shows how to use "state storage" to
    // store the instrument configuration in memory.	
	
	/*
		' This program commands with channel 1 of the intrument, you can change
		' the number '1' after each command to '2' to select channel 2.
	*/
			
	CHECK(Fgen->WriteString("*RST")); // Reset the function generator
	Fgen->Clear(); // Clear errors and status registers
			
    CHECK(Fgen->WriteString("OUTPut1:LOAD 50")); // Output termination is 50 Ohms
    CHECK(Fgen->WriteString("FUNCtion1:SHAPe SINusoid")); // Carrier waveshape is sine wave
    CHECK(Fgen->WriteString("FREQuency1 5000;VOLTage 5")); // Carrier frequency is 5 kHz @ 5 Vpp
    CHECK(Fgen->WriteString("AM1:INTernal:FUNCtion SINusoid")); // Modulating waveshape is sine
    CHECK(Fgen->WriteString("AM1:INTernal:FREQuency 200")); // Modulation frequency is 200 Hz
    CHECK(Fgen->WriteString("AM1:DEPTh 80")); // Modulation depth is 80%
    CHECK(Fgen->WriteString("AM1:STATe ON")); // Turn AM modulation on

	CHECK(Fgen->WriteString("OUTPut1 ON")); // Turn on the instrument output
    CHECK(Fgen->WriteString("*SAV 1")); // Store state in memory location 1

    // Use the "*RCL 1" command to recall the stored state

}
