
/****************************************************************************
	'    Copyright  2006 Agilent Technologies Inc. All rights
	'    reserved.
	'
	' You have a royalty-free right to use, modify, reproduce and distribute
	' the Sample Application Files (and/or any modified version) in any way
	' you find useful, provided that you agree that Agilent has no
	' warranty,  obligations or liability for any Sample Application Files.
	'
	' Agilent Technologies provides programming examples for illustration only,
	' This sample program assumes that you are familiar with the programming
	' language being demonstrated and the tools used to create and debug
	' procedures. Agilent support engineers can help explain the
	' functionality of Agilent software components and associated
	' commands, but they will not modify these samples to provide added
	' functionality or construct procedures to meet your specific needs.
 ****************************************************************************/

#include <stdio.h>

#define	CHECK(func)	\
do {\
    long _s = (func);\
    if (_s <= 0)\
    {\
	fprintf(stderr, "Error: %s returned %d\n", #func, _s);\
	exit(0);\
    }\
} while (0)

// Specify the default address
#define DEFAULT_LOGICAL_ADDRESS OLESTR("GPIB1::11::INSTR")

#import "visacom.tlb" no_namespace
#import "agtrm.dll" no_namespace

void main()
{
	BSTR     TxtAddress = DEFAULT_LOGICAL_ADDRESS;

	//
	// This program is an example program intended for use with
	// Microsoft Visual C++ 2005 and the Agilent VISA COM objects.
	//
	// "VISA COM 1.0 Type Library", corresponds to VISACOM.tlb
	// "Agilent VISA COM Resource Manager 1.0", corresponds to AgtRM.DLL
	//
	// Use the statement "#import "VisaCom.tlb" no_namespace" to import 
	// the VISA COM type library. 
    // Create a variable of type IResourceManagerPtr to hold the reference to the object.  
	// To create the object, use  "io_mgr.CreateInstance( __uuidof(SRMCls) )".
	//

	IResourceManagerPtr io_mgr;
    IMessagePtr Fgen;

    CoInitialize(NULL);

    io_mgr.CreateInstance(__uuidof(SRMCls));

	Fgen = io_mgr->Open(TxtAddress, NO_LOCK, 2000, "");
		
    // This program uses low-level SCPI commands to configure
    // the function gnerator to output an PWM waveform.
    // The pulse is set up with a duty cycle of 35% and a depth
    // of 15%, and will vary in width from 20% to 50% with the
    // modulation.  The pulse may also be configured in time
    // units (pulse width and deviation) rather than duty cycle
    // if preferred.

	/*
	' This program commands with channel 1 of the intrument, you can change
    ' the number '1' after each command to '2' to select channel 2.
	*/
	
	CHECK(Fgen->WriteString("*RST")); // Reset the function generator
	Fgen->Clear(); // Clear errors and status registers
			
    CHECK(Fgen->WriteString("OUTPut1:LOAD 50")); // Output termination is 50 Ohms
    CHECK(Fgen->WriteString("FUNCtion1:SHAPe PULSe")); // Carrier waveshape is pulse
    CHECK(Fgen->WriteString("FREQuency1 5000")); // Carrier frequency is 5 kHz
    CHECK(Fgen->WriteString("VOLTage1:LOW 0")); // Set parameters to 5 V TTL
    CHECK(Fgen->WriteString("VOLTage1:HIGH 5")); 
    CHECK(Fgen->WriteString("FUNCtion1:PULSe:DCYCle 35")); // Begin with 35% duty cycle

    CHECK(Fgen->WriteString("PWM1:INTernal:FUNCtion TRIangle")); // Modulating waveshape is triangle
    CHECK(Fgen->WriteString("PWM1:INTernal:FREQuency 2")); // Modulation frequency is 2 Hz
    CHECK(Fgen->WriteString("PWM1:DEViation:DCYCle 15")); // Modulation depth is 15%
    CHECK(Fgen->WriteString("PWM1:SOURce INTernal")); // Use internal signal for modulation
    // If using an external signal for PWM, connect the signal to the rear-panel
    // BNC and use the command PWM:SOURce EXTernal

    CHECK(Fgen->WriteString("PWM1:STATe ON")); // Turn PWM modulation on
    CHECK(Fgen->WriteString("OUTPut1 ON")); // Turn on the instrument output
}