
/****************************************************************************
	'    Copyright  2006 Agilent Technologies Inc. All rights
	'    reserved.
	'
	' You have a royalty-free right to use, modify, reproduce and distribute
	' the Sample Application Files (and/or any modified version) in any way
	' you find useful, provided that you agree that Agilent has no
	' warranty,  obligations or liability for any Sample Application Files.
	'
	' Agilent Technologies provides programming examples for illustration only,
	' This sample program assumes that you are familiar with the programming
	' language being demonstrated and the tools used to create and debug
	' procedures. Agilent support engineers can help explain the
	' functionality of Agilent software components and associated
	' commands, but they will not modify these samples to provide added
	' functionality or construct procedures to meet your specific needs.
 ****************************************************************************/

#include <string.h>
#include <stdlib.h>
#include <stdio.h>
#include <visa.h>

#define	CHECK(func)	\
do {\
    ViStatus _s = (func);\
    if (_s < 0)\
    {\
	fprintf(stderr, "Error: %s returned %d\n", #func, _s);\
	exit(0);\
    }\
} while (0)

/* Specify the default address */
#define DEFAULT_LOGICAL_ADDRESS "GPIB1::11::INSTR"


void main()
{
	ViSession   viDefaultRM, Instrument;
	ViRsrc      TxtAddress = DEFAULT_LOGICAL_ADDRESS;
	ViUInt32	actual;
	char SCPIcmd[128];

	CHECK(viOpenDefaultRM(&viDefaultRM));
	CHECK(viOpen(viDefaultRM, TxtAddress, VI_NULL, 2500, &Instrument));
	
	/*
		' This program is an example program intended for use with
		' Microsoft Visual C++ 6.0 and requires the VISA installed.
	 */
		
	/*
		' This program sets up a linear sweep using a sinusoid
		' waveform.  It sets the start and stop frequency and sweep
		' time.

  
		' This program commands with channel 1 of the intrument, you can change
		' the number '1' after each command to '2' to select channel 2.
	 */
		
	strcpy(SCPIcmd,"*RST\n");  /* Reset the function generator */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
	strcpy(SCPIcmd,"*CLS\n");  /* Clear errors and status registers */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));		

	strcpy(SCPIcmd,"FUNCtion1 SINusoid\n");  /* Select waveshape */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));

	strcpy(SCPIcmd, "OUTPut1:LOAD 50\n");    /* Set the load impedance in Ohms (50 Ohms default) */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
	strcpy(SCPIcmd, "VOLTage1 1\n");         /* Set the amplitude to 1 Vpp */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));

	strcpy(SCPIcmd, "SWEep1:SPACing LINear\n");   /* Set Linear or LOGarithmic spacing */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
	strcpy(SCPIcmd, "SWEep1:TIME 1\n");           /* Sweep time is 1 second */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
	strcpy(SCPIcmd, "FREQuency1:STARt 100\n");    /* Start frequency is 100 Hz */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
	strcpy(SCPIcmd, "FREQuency1:STOP 20e3\n");    /*Stop frequency is 20 kHz */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
	

		
	strcpy(SCPIcmd, "OUTPut1 ON\n");         /* Turn on the instrument output */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
	strcpy(SCPIcmd, "SWEep1:STATe ON\n");    /* Turn sweep on */
	CHECK(viWrite(Instrument, SCPIcmd, (ViUInt32)strlen(SCPIcmd), &actual));
		
	CHECK(viClose(Instrument));
	CHECK(viClose(viDefaultRM));
}
