
/****************************************************************************
	'    Copyright  2006 Agilent Technologies Inc. All rights
	'    reserved.
	'
	' You have a royalty-free right to use, modify, reproduce and distribute
	' the Sample Application Files (and/or any modified version) in any way
	' you find useful, provided that you agree that Agilent has no
	' warranty,  obligations or liability for any Sample Application Files.
	'
	' Agilent Technologies provides programming examples for illustration only,
	' This sample program assumes that you are familiar with the programming
	' language being demonstrated and the tools used to create and debug
	' procedures. Agilent support engineers can help explain the
	' functionality of Agilent software components and associated
	' commands, but they will not modify these samples to provide added
	' functionality or construct procedures to meet your specific needs.
 ****************************************************************************/

#include <stdio.h>

#define	CHECK(func)	\
do {\
    long _s = (func);\
    if (_s <= 0)\
    {\
	fprintf(stderr, "Error: %s returned %d\n", #func, _s);\
	exit(0);\
    }\
} while (0)

// Specify the default address
#define DEFAULT_LOGICAL_ADDRESS OLESTR("GPIB1::11::INSTR")

#import "visacom.tlb" no_namespace
#import "agtrm.dll" no_namespace

void main()
{
	BSTR     TxtAddress = DEFAULT_LOGICAL_ADDRESS;
	

	//
	// This program is an example program intended for use with
	// Microsoft Visual C++ 6.0 and the Agilent VISA COM objects.
	//
	// "VISA COM 1.0 Type Library", corresponds to VISACOM.tlb
	// "Agilent VISA COM Resource Manager 1.0", corresponds to AgtRM.DLL
	//
	// Use the statement "#import "VisaCom.tlb" no_namespace" to import 
	// the VISA COM type library. 
    // Create a variable of type IResourceManagerPtr to hold the reference to the object.  
	// To create the object, use  "io_mgr.CreateInstance( __uuidof(SRMCls) )".
	//

    unsigned short i;
    char SCPIcmd[10000];

	IResourceManagerPtr io_mgr;
    IMessagePtr Fgen;

    CoInitialize(NULL);

    io_mgr.CreateInstance(__uuidof(SRMCls));

	Fgen = io_mgr->Open(TxtAddress, NO_LOCK, 2000, "");
		
	// This program uses the arbitrary waveform function to
    // download and output a square wave pulse with a calculated
    // rise time and fall time.  The waveform consists of 4000
    // points downloaded to the function generator as ASCII data.
	
	/*
		' This program commands with channel 1 of the intrument, you can change
		' the number '1' after each command to '2' to select channel 2.
	*/
			
	CHECK(Fgen->WriteString("*RST"));	// Reset the function generator
	Fgen->Clear();						// Clear errors and status registers
	Fgen->Timeout = 40000;				// Set 40 seconds timeout
			
    // Compute waveform
    fprintf(stderr, "Computing Waveform...\n");

	strcpy(SCPIcmd, "DATA1 VOLATILE");
	for(i = 1; i <= 5; i++)				// Set rise time (5 points)
		sprintf(SCPIcmd, "%s,%3.1f", SCPIcmd, (double)(i - 1)/5);

	for(i = 6; i <= 205; i++)
		strcat(SCPIcmd, ",1");			// Set pulse width (200 points)

	for(i = 206; i <= 210; i++)			// Set fall time (5 points)
		sprintf(SCPIcmd, "%s,%3.1f", SCPIcmd, (double)(210 - i)/5);

	for(i = 211; i <= 4000; i++)
		strcat(SCPIcmd, ",0");			// Set remaining points to zero

	strcat(SCPIcmd,"\n");
	
	// Download data points to volatile memory
		
	fprintf(stderr,"Downloading Arb...\n");

	CHECK(Fgen->WriteString(SCPIcmd));
		
	fprintf(stderr,"Download Complete\n");
    // Download data points to volatile memory //

    // Set up arbitrary waveform and output //

    CHECK(Fgen->WriteString("DATA1:COPY PULSE, VOLATILE"));	// Copy arb to non-volatile memory
    CHECK(Fgen->WriteString("FUNCtion1:USER PULSE"));		// Select the active arb waveform
    CHECK(Fgen->WriteString("FUNCtion1:SHAPe USER"));		// Output the selected arb waveform

    CHECK(Fgen->WriteString("OUTPut1:LOAD 50"));				// Output termination is 50 Ohms
    CHECK(Fgen->WriteString("FREQuency1 5000;VOLTage 5"));	// Output frequency is 5 kHz @ 5 Vpp
    CHECK(Fgen->WriteString("OUTPut1 ON"));					// Enable output
}
