
/****************************************************************************
	'    Copyright  2006 Agilent Technologies Inc. All rights
	'    reserved.
	'
	' You have a royalty-free right to use, modify, reproduce and distribute
	' the Sample Application Files (and/or any modified version) in any way
	' you find useful, provided that you agree that Agilent has no
	' warranty,  obligations or liability for any Sample Application Files.
	'
	' Agilent Technologies provides programming examples for illustration only,
	' This sample program assumes that you are familiar with the programming
	' language being demonstrated and the tools used to create and debug
	' procedures. Agilent support engineers can help explain the
	' functionality of Agilent software components and associated
	' commands, but they will not modify these samples to provide added
	' functionality or construct procedures to meet your specific needs.
 ****************************************************************************/

#include <stdio.h>
#include <time.h>

#define	CHECK(func)	\
do {\
    long _s = (func);\
    if (_s <= 0)\
    {\
	fprintf(stderr, "Error: %s returned %d\n", #func, _s);\
	exit(0);\
    }\
} while (0)

// Specify the default address
#define DEFAULT_LOGICAL_ADDRESS OLESTR("GPIB1::11::INSTR")

#import "visacom.tlb" no_namespace
#import "agtrm.dll" no_namespace

void sleep( clock_t wait );

void main()
{
	BSTR     TxtAddress = DEFAULT_LOGICAL_ADDRESS;
	long i;
	char SCPIcmd[128];
	//
	// This program is an example program intended for use with
	// Microsoft Visual C++ 6.0 and the Agilent VISA COM objects.
	//
	// "VISA COM 1.0 Type Library", corresponds to VISACOM.tlb
	// "Agilent VISA COM Resource Manager 1.0", corresponds to AgtRM.DLL
	//
	// Use the statement "#import "VisaCom.tlb" no_namespace" to import 
	// the VISA COM type library. 
    // Create a variable of type IResourceManagerPtr to hold the reference to the object.  
	// To create the object, use  "io_mgr.CreateInstance( __uuidof(SRMCls) )".
	//

	IResourceManagerPtr io_mgr;
    IMessagePtr Fgen;

    CoInitialize(NULL);

    io_mgr.CreateInstance(__uuidof(SRMCls));

	Fgen = io_mgr->Open(TxtAddress, NO_LOCK, 2000, "");
		
    // This program sets up a pulse waveshape and adjusts the edge
    // time.  It also shows the use of high and low voltage levels
    // and period.  The edge time is adjusted by 5 nsec increments.	

	/*
		' This program commands with channel 1 of the intrument, you can change
		' the number '1' after each command to '2' to select channel 2.
	*/
			
	CHECK(Fgen->WriteString("*RST")); // Reset the function generator
	Fgen->Clear(); // Clear errors and status registers
			
    CHECK(Fgen->WriteString("FUNCtion1 PULSe")); // Select pulse waveshape

    CHECK(Fgen->WriteString("OUTPut1:LOAD 50")); // Set the load impedance to 50 Ohms (default)
    CHECK(Fgen->WriteString("VOLTage1:LOW 0")); // Low level = 0 V
    CHECK(Fgen->WriteString("VOLTage1:HIGH 0.75")); // High level = .75 V

    CHECK(Fgen->WriteString("PULSe1:PERiod 1e-3")); // 1 ms intervals
    CHECK(Fgen->WriteString("PULSe1:WIDTh 100e-6")); // Pulse width is 100 us
    CHECK(Fgen->WriteString("PULSe1:TRANsition 10e-9")); // Edge time is 10 ns (rise time = fall time)
    CHECK(Fgen->WriteString("OUTPut1 ON")); // Turn on the instrument output

    // Vary edge by 5 nsec steps
    for (i=0; i<=18; i++)
	{
		sprintf(SCPIcmd, "PULSe1:TRANsition %.10f\n", 0.00000001 + i * 0.000000005);
		CHECK(Fgen->WriteString(SCPIcmd));
        sleep((clock_t)(0.3*CLOCKS_PER_SEC)); // Wait 300 msec //
    }

}

// Pauses for a specified number of milliseconds. //
void sleep( clock_t wait )
{
   clock_t goal;
   goal = wait + clock();
   while( goal > clock() )
      ;
}

