
/****************************************************************************
	'    Copyright  2006 Agilent Technologies Inc. All rights
	'    reserved.
	'
	' You have a royalty-free right to use, modify, reproduce and distribute
	' the Sample Application Files (and/or any modified version) in any way
	' you find useful, provided that you agree that Agilent has no
	' warranty,  obligations or liability for any Sample Application Files.
	'
	' Agilent Technologies provides programming examples for illustration only,
	' This sample program assumes that you are familiar with the programming
	' language being demonstrated and the tools used to create and debug
	' procedures. Agilent support engineers can help explain the
	' functionality of Agilent software components and associated
	' commands, but they will not modify these samples to provide added
	' functionality or construct procedures to meet your specific needs.
 ****************************************************************************/

#include <stdio.h>

#define	CHECK(func)	\
do {\
    long _s = (func);\
    if (_s <= 0)\
    {\
	fprintf(stderr, "Error: %s returned %d\n", #func, _s);\
	exit(0);\
    }\
} while (0)

// Specify the default address
#define DEFAULT_LOGICAL_ADDRESS OLESTR("GPIB1::11::INSTR")

#import "visacom.tlb" no_namespace
#import "agtrm.dll" no_namespace

void main()
{
	BSTR     TxtAddress = DEFAULT_LOGICAL_ADDRESS;

	//
	// This program is an example program intended for use with
	// Microsoft Visual C++ 6.0 and the Agilent VISA COM objects.
	//
	// "VISA COM 1.0 Type Library", corresponds to VISACOM.tlb
	// "Agilent VISA COM Resource Manager 1.0", corresponds to AgtRM.DLL
	//
	// Use the statement "#import "VisaCom.tlb" no_namespace" to import 
	// the VISA COM type library. 
    // Create a variable of type IResourceManagerPtr to hold the reference to the object.  
	// To create the object, use  "io_mgr.CreateInstance( __uuidof(SRMCls) )".
	//

	IResourceManagerPtr io_mgr;
    IMessagePtr Fgen;

    CoInitialize(NULL);

    io_mgr.CreateInstance(__uuidof(SRMCls));

	Fgen = io_mgr->Open(TxtAddress, NO_LOCK, 2000, "");
		
	/*
	' This program sets up a waveform by selecting the waveshape
    ' and adjusting the frequency, amplitude, and offset.
    ' This program shows how to commands with 2 channel by inserting
    ' the number '1' after the command to select channel 1 and the number '2'
    ' to select channel 2 in order to set up different waveform parameters.
	*/
		
			
	CHECK(Fgen->WriteString("*RST")); // Reset the function generator
	Fgen->Clear(); // Clear errors and status registers
	
	// Channel 1
	CHECK(Fgen->WriteString("FUNCtion1 SINusoid")); // Select waveshape
	// Other options are SQUare, RAMP, PULSe, NOISe, DC, and USER
	CHECK(Fgen->WriteString("OUTPut1:LOAD 50")); // Set the load impedance in Ohms (50 Ohms default)
	// May also be INFinity, as when using oscilloscope or DMM
			
	CHECK(Fgen->WriteString("FREQuency1 2500"));  // Set the frequency.
	CHECK(Fgen->WriteString("VOLTage1 1.2")); // Set the amplitude in Vpp.  Also see VOLTage:UNIT
	CHECK(Fgen->WriteString("VOLTage1:OFFSet 0.4")); // Set the offset in Volts
	// Voltage may also be set as VOLTage:HIGH and VOLTage:LOW for low level and high level
			
	CHECK(Fgen->WriteString("OUTPut1 ON")); // Turn on the instrument output



	// Channel 2
	CHECK(Fgen->WriteString("FUNCtion2 SINusoid")); // Select waveshape
	// Other options are SQUare, RAMP, PULSe, NOISe, DC, and USER
	CHECK(Fgen->WriteString("OUTPut2:LOAD 50")); // Set the load impedance in Ohms (50 Ohms default)
	// May also be INFinity, as when using oscilloscope or DMM
			
	CHECK(Fgen->WriteString("FREQuency2 5000"));  // Set the frequency.
	CHECK(Fgen->WriteString("VOLTage2 2")); // Set the amplitude in Vpp.  Also see VOLTage:UNIT
	CHECK(Fgen->WriteString("VOLTage2:OFFSet 1")); // Set the offset in Volts
	// Voltage may also be set as VOLTage:HIGH and VOLTage:LOW for low level and high level
			
	CHECK(Fgen->WriteString("OUTPut2 ON")); // Turn on the instrument output

}
